package com.ff.apimngr.controller;

import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import com.ff.apimngr.dao.ApiMapper;
import com.ff.apimngr.dao.UserMapper;
import com.ff.apimngr.entity.*;
import com.ff.apimngr.service.*;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.ff.apimngr.jwt.JwtHelper;

import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

/**
 * 接口管理
 */
//@io.swagger.annotations.Api(tags = "接口管理",position = 2)
@RestController
@RequestMapping("/api/apimngr")
public class ApiController {

	@Resource
	private ApiService apiService;

	@Resource
	private ApiTypeService apiTypeService;
	
	@Autowired
	private AppService appService;

	@Resource
	private AppApiService appApiService;

	@Resource
	private UserService userService;

	@Resource
	private AuthService authService;

	@Autowired
	private ApiVersionService apiVersionService;

	@Resource
	private ApiMapper apiMapper;

	@Autowired
	private UserMapper userMapper;

	@Resource
	private RoleService roleService;

	@ApiOperation(value = "根据id获取接口", notes = "根据id获取接口", tags = "接口管理")
	@GetMapping(value = "/findbyid")
	public Map<String, Object> getApiById(@ApiParam(value = "接口id", required = true) @RequestParam Integer id) {
		Map<String, Object> result = new HashMap<>();
		Api api = apiService.findApiById(id);
		if (null == api) {
			result.put("code", 10001);
			result.put("message", "未查询到此接口");
			return result;
		}
		api.setUrl(null);
		//数据对象
		Map<String, Object> dataMap = new HashMap<>();
		dataMap.put("api", api);
		dataMap.put("apiInvokeNum", apiService.getInvokeApiNum(id));
		dataMap.put("apiCollectNum", apiService.getCollectApiNum(id));
		dataMap.put("apiBrowserNum", api.getBrowserCount() == null ? 0 : api.getBrowserCount());
		
		result.put("data", dataMap);
		result.put("code", 10000);
		result.put("message", "获取成功");

		// 增加浏览数量
		apiService.incrBrowserCount(id);
		return result;
	}

	@ApiOperation(value = "根据id获取血缘关系", notes = "根据id获取血缘关系", tags = "接口管理")
	@GetMapping(value = "/findRelationbyid")
	public Map<String, Object> getRelationById(@ApiParam(value = "接口id", required = true) @RequestParam Integer id) {
		Map<String, Object> result = new HashMap<>();
		Api api = apiService.findApiById(id);
		if (null == api) {
			result.put("code", 10001);
			result.put("message", "未查询到此接口");
			return result;
		}
		api.setUrl(null);
		//数据对象
		Map<String, Object> dataMap = new HashMap<>();
		dataMap.put("api", api);
		// 查询应用信息
		dataMap.put("applist", appService.listAppsByApiId(id));

		result.put("data", dataMap);
		result.put("code", 10000);
		result.put("message", "查询成功");
		return result;
	}

	@ApiOperation(value = "根据姓名获取接口", notes = "根据姓名获取接口", hidden = true)
	@GetMapping(value = "/findbyname")
	public Map<String, Object> findApiByName(@ApiParam(value = "接口姓名", required = true) @RequestParam String name) {
		Map<String, Object> result = new HashMap<>();
		Api api = apiService.findApiByName(name);
		if (null == api) {
			result.put("code", 10001);
			result.put("message", "未查询到此接口");
			return result;
		}
		api.setUrl(null);
		result.put("data", api);
		result.put("code", 10000);
		result.put("message", "查询成功");

		// 增加浏览数量
		apiService.incrBrowserCount(api.getId());
		return result;
	}

	@ApiOperation(value = "创建接口", notes = "创建接口", tags = "接口管理")
	@PostMapping(value = "/insert")
	public Map<String, Object> insertApi(@ApiParam(value = "接口名字", required = true) @RequestParam String name,
			@ApiParam(value = "请求地址", required = true) @RequestParam String url,
			@ApiParam(value = "调用量限制", required = true) @RequestParam String callLimit,
			@ApiParam(value = "QPS限制", required = true) @RequestParam String qpsLimit,
			@ApiParam(value = "状态", required = true) @RequestParam Integer status,
			@ApiParam(value = "接口类型id", required = true) @RequestParam String apiTypeId,
			@ApiParam(value = "备注", required = false) @RequestParam(required = false) String description,
			@ApiParam(value = "能力版本", required = false) @RequestParam(required = false) String version,
			@ApiParam(value = "开发文档", required = false) @RequestParam(required = false) String docUrl,
			@ApiParam(value = "json", required = false) @RequestParam(required = false) String extJson,
			HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		if (!checkHasAdminAuth(request)) {
			result.put("code", 10001);
			result.put("message", "没有权限");
			return result;
		}
		Api api = apiService.findApiByName(name);
		if (null != api) {
			result.put("code", 10002);
			result.put("message", "接口名已存在");
			return result;
		}
		api = new Api();
		api.setName(name);
		api.setUrl(url);
		api.setCallLimit(callLimit);
		api.setQpsLimit(qpsLimit);
		api.setCreateBy(getAccount(request));
		api.setExtJson(extJson);
		api.setApplyStatus(2);
		api.setApiType(apiTypeService.findApiTypeById(Integer.valueOf(apiTypeId)));
		api.setStatus(status);// 1=正常 0=不正常 2=测试（未发布） 3=VIP
		if (null == description) {
			api.setDescription("");
		} else {
			api.setDescription(description);
		}

		if (null == version) {
			api.setVersion("");
		} else {
			api.setVersion(version);
		}
		if (null == docUrl) {
			api.setDocUrl("");
		} else {
			api.setDocUrl(docUrl);
		}
		boolean ret = apiService.insertApi(api);
		if (ret) {
			List<Role> list = roleService.getRoleList();
			if(list != null && list.size() > 0) {
				for (Role role : list) {
					Auth auth = new Auth();
					auth.setApi(api);
					auth.setRole(role);
					auth.setAccreditStatus(0);
					authService.insertAuth(auth);
				}
			}
			// 插入版本记录
			ApiVersion apiVersion = new ApiVersion();
			apiVersion.setApiId(api.getId());
			apiVersion.setCreateBy(getAccount(request));
			apiVersion.setOldVersion(version);
			apiVersion.setRemark(description);
			apiVersionService.save(apiVersion);
		}

		result.put("code", 10000);
		result.put("message", "创建成功");
		return result;
	}
	@ApiOperation(value = "申请新增接口", notes = "申请新增接口", tags = "接口管理")
	@PostMapping(value = "/applyInsertApi")
	public Map<String, Object> applyInsertApi(@ApiParam(value = "联系方式", required = true) @RequestParam String mobile,
											  @ApiParam(value = "需求描述", required = true) @RequestParam(required = false) String description,
											  @ApiParam(value = "接口名", required = true) @RequestParam(required = false) String apiName,
			HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		String token = request.getHeader("token");
		String account = "";
		account = JwtHelper.parseToken(token);
		User user = userMapper.findUserByAccount(account);
		if (null == user) {
			result.put("code", 1001);
			result.put("message", "用户信息不存在");
			return result;
		}
		Api api  = new Api();
		api.setMobile(mobile);
		if (null == description) {
			api.setDescription("");
		} else {
			api.setDescription(description);
		}
		api.setApplyUserId(user.getId());
		api.setName(apiName);
		api.setUrl("");
		api.setApiType(null);
		api.setApplyStatus(0);//审核状态:0 未审核、1 已审核待开发 2已审核已完成 3审核不通过
		api.setIsApply(1);
		Date date = Calendar.getInstance().getTime();
		api.setApplyTime(date);
		apiMapper.insert(api);
		result.put("code", 10000);
		result.put("message", "创建成功");
		return result;
	}

	@ApiOperation(value = "新增接口审核", notes = "新增接口审核",tags = "新增接口审核")
	@PostMapping(value = "/examineApi")
	public Map<String, Object> update(@RequestParam(value = "apiId", required = true) Integer apiId,
									  @RequestParam(value = "status", required = true) Integer status,
									  @RequestParam(value = "disagreeReason", required = false)  String disagreeReason,
									  HttpServletRequest request)
	{
		Map<String, Object> result = new HashMap<>();
		String token = request.getHeader("token");
		String account = "";
		account = JwtHelper.parseToken(token);
		User user = userMapper.findUserByAccount(account);
		if (null == user) {
			result.put("code", 1001);
			result.put("message", "用户信息不存在");
			return result;
		}

		Api api  = new Api();
		api.setId(apiId);
		api.setApplyStatus(status);
		api.setCreateBy(user.getAccount());
		api.setDisagreeReason(disagreeReason);
		apiService.updateApi(api);
		result.put("code", 10000);
		result.put("message", "审核成功");
		return result;
	}


	@ApiOperation(value = "新增申请列表", notes = "新增申请列表",tags = "需求申请")
	@PostMapping(value = "/applyList")
	public Map<String, Object> applyList(@RequestParam(value = "apiName", required = false) String apiName,
										 @RequestParam(value = "apiType", required = false) Integer apiType,
										 HttpServletRequest request)
	{
		Map<String, Object> result = new HashMap<>();
		String token = request.getHeader("token");
		String account = "";
		account = JwtHelper.parseToken(token);
		User user = userMapper.findUserByAccount(account);
		if (null == user) {
			result.put("code", 1001);
			result.put("message", "用户信息不存在");
			return result;
		}
		result.put("data",apiService.getApplyList(user.getId(),apiName,apiType));
		result.put("code", 10000);
		result.put("message", "查询需求申请列表成功");
		return result;
	}


	@ApiOperation(value = "需求审核列表", notes = "需求申请",tags = "需求申请")
	@PostMapping(value = "/examineList")
	public Map<String, Object> examineList(@RequestParam(value = "status", required = false) Integer status,
										   @RequestParam(value = "userName", required = false)  String userName,
										   HttpServletRequest request)
	{
		Map<String, Object> result = new HashMap<>();
		result.put("data",apiService.getExamineList(status,userName));
		result.put("code", 10000);
		result.put("message", "查询需求审核列表成功");
		return result;
	}




	@ApiOperation(value = "创建接口", notes = "创建接口", hidden = true)
	@PostMapping(value = "/insertNoAuth")
	public Map<String, Object> insertNoAuth( @RequestBody ApiReleaseDTO apiReleaseDTO,
			HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		Api api = apiService.findApiByName(apiReleaseDTO.getName());
		if (null != api) {
			result.put("code", 10002);
			result.put("message", "接口名已存在");
			return result;
		}
		api = new Api();
		api.setName(apiReleaseDTO.getName());
		api.setUrl(apiReleaseDTO.getUrl());
		api.setCallLimit(apiReleaseDTO.getCallLimit());
		api.setQpsLimit(apiReleaseDTO.getQpsLimit());
		api.setExtJson(apiReleaseDTO.getExtJson());
		api.setApiType(apiTypeService.findApiTypeById(Integer.valueOf(apiReleaseDTO.getApiTypeId())));
		api.setCreateBy(getAccount(request));
		api.setApplyStatus(2);
		api.setStatus(apiReleaseDTO.getStatus());// 1=正常 0=不正常 2=测试（未发布） 3=VIP
		if (null == apiReleaseDTO.getDescription()) {
			api.setDescription("");
		} else {
			api.setDescription(apiReleaseDTO.getDescription());
		}

		if (null == apiReleaseDTO.getVersion()) {
			api.setVersion("");
		} else {
			api.setVersion(apiReleaseDTO.getVersion());
		}
		if (null == apiReleaseDTO.getDocUrl()) {
			api.setDocUrl("");
		} else {
			api.setDocUrl(apiReleaseDTO.getDocUrl());
		}
		boolean ret = apiService.insertApi(api);
		if (ret) {
			// 插入版本记录
			ApiVersion apiVersion = new ApiVersion();
			apiVersion.setApiId(api.getId());
			apiVersion.setCreateBy(getAccount(request));
			apiVersion.setOldVersion(apiReleaseDTO.getVersion());
			apiVersion.setRemark(apiReleaseDTO.getDescription());
			apiVersionService.save(apiVersion);
		}
		result.put("code", 10000);
		result.put("message", "创建成功");
		return result;
	}

	@ApiOperation(value = "更新接口", notes = "更新接口", tags = "接口管理")
	@PostMapping(value = "/update")
	public Map<String, Object> updateApi(@ApiParam(value = "接口id", required = true) @RequestParam String id,
			@ApiParam(value = "接口名字", required = true) @RequestParam String name,
			@ApiParam(value = "请求地址", required = true) @RequestParam String url,
			@ApiParam(value = "调用量限制", required = true) @RequestParam String callLimit,
			@ApiParam(value = "QPS限制", required = true) @RequestParam String qpsLimit,
			@ApiParam(value = "状态", required = true) @RequestParam Integer status,
			@ApiParam(value = "接口类型id", required = true) @RequestParam String apiTypeId,
			@ApiParam(value = "备注", required = false) @RequestParam(required = false) String description,
			@ApiParam(value = "能力版本", required = false) @RequestParam(required = false) String version,
			@ApiParam(value = "开发文档", required = false) @RequestParam(required = false) String docUrl,
			@ApiParam(value = "json", required = false) @RequestParam(required = false) String extJson,
			HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		if (!checkHasAdminAuth(request)) {
			result.put("code", 10001);
			result.put("message", "没有权限");
			return result;
		}
		Api api = apiService.findApiById(Integer.valueOf(id));
		if (null == api) {
			result.put("code", 10001);
			result.put("message", "接口不存在");
			return result;
		}
		String oldVersion = api.getVersion();
		Api check = apiService.findApiByName(name);
		if (check != null && !check.getId().equals(Integer.valueOf(id))) {
			result.put("code", 10001);
			result.put("message", "能力名称已存在,不可重复");
			return result;
		}
		api.setName(name);
		api.setExtJson(extJson);
		api.setUrl(url);
		api.setCallLimit(callLimit);
		api.setQpsLimit(qpsLimit);
		api.setStatus(status);
		api.setApiType(apiTypeService.findApiTypeById(Integer.valueOf(apiTypeId)));

		api.setDescription(description);
		api.setVersion(version);
		api.setDocUrl(docUrl);

		boolean rst = apiService.updateApi(api);
		if (rst && !StringUtils.equals(oldVersion, version)) {
			// 插入版本记录
			ApiVersion apiVersion = new ApiVersion();
			apiVersion.setApiId(Integer.valueOf(id));
			apiVersion.setCreateBy(getAccount(request));
			apiVersion.setOldVersion(oldVersion);
			apiVersion.setRemark(description);
			apiVersionService.save(apiVersion);
		}
		result.put("code", 10000);
		result.put("message", "更新成功");
		return result;
	}

	@ApiOperation(value = "根据id删除接口", notes = "根据id删除接口", tags = "接口管理")
	@PostMapping(value = "/delete")
	public Map<String, Object> deleteApi(@ApiParam(value = "接口id", required = true) @RequestParam String id,
			HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		if (!checkHasAdminAuth(request)) {
			result.put("code", 10001);
			result.put("message", "没有权限");
			return result;
		}
		Api api = apiService.findApiById(Integer.valueOf(id));
		if (null == api) {
			result.put("code", 10001);
			result.put("message", "删除失败，接口不存在");
			return result;
		}
		// 检查接口是否在被应用使用
		List<AppApi> list = appApiService.listAppApisByApiId(Integer.valueOf(id));
		if (null != list && list.size() > 0) {
			result.put("code", 10002);
			result.put("message", "删除失败，有应用在使用此接口!");
			return result;
		}
		boolean rst = apiService.deleteApiById(Integer.valueOf(id));
		if (rst) {
			result.put("code", 10000);
			result.put("message", "删除成功");
		} else {
			result.put("code", 10002);
			result.put("message", "删除失败");
		}

		return result;
	}

	@ApiOperation(value = "根据id停用/启动接口", notes = "根据id停用/启动接口", tags = "接口管理")
	@PostMapping(value = "/disable")
	public Map<String, Object> disableApi(@ApiParam(value = "接口id", required = true) @RequestParam String id,
			@ApiParam(value = "停用/启用接口", required = true) @RequestParam Integer status, HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		if (!checkHasAdminAuth(request)) {
			result.put("code", 10001);
			result.put("message", "没有权限");
			return result;
		}

		Api api = apiService.findApiById(Integer.valueOf(id));
		if (null == api) {
			result.put("code", 10001);
			result.put("message", "更新接口失败，接口不存在");
			return result;
		}
		api.setStatus(status);
		boolean rst = apiService.updateApi(api);
		if (rst) {
			result.put("code", 10000);
			result.put("message", "停用启用接口成功");
		} else {
			result.put("code", 10002);
			result.put("message", "停用启用接口失败");
		}

		return result;
	}

	@ApiOperation(value = "获取接口列表", notes = "获取接口列表", tags = "接口管理")
	@GetMapping(value = "/list")
	public Map<String, Object> searchApis(HttpServletRequest request,
			@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag,
			@ApiParam(value = "授权状态 0 未授权 1 已授权 2 待授权", required = false) @RequestParam(required = false) Integer accreditStatus,
			@ApiParam(value = "授权状态 0 未发布 1 发布", required = false) @RequestParam(required = false) Integer status,
			@ApiParam(value = "能力角色id", required = false) @RequestParam(required = false) Integer roleId,
			@ApiParam(value = "APPID", required = false) @RequestParam(required = false) String appId,
			@ApiParam(value = "ApiTypeID", required = false) @RequestParam(required = false) Integer apiTypeId) {
		Map<String, Object> result = new HashMap<>();
		List<Api> list = apiService.listApi(tag, accreditStatus, status,roleId,apiTypeId);
		System.out.println("list = " +list.size() );
		if (StringUtils.isNotBlank(appId)) {
			String token = request.getHeader("token");
			String account = JwtHelper.parseToken(token);
			Integer userId = null;
			if (null != account && account.length() > 0) {
				User user = userService.findUserByAccount(account);
				if (null == user) {
					result.put("code", 10001);
					result.put("message", "接口调用失败");
					return result;
				}
				Role role = user.getRole();
				if (null != role) {
					if (role.getRoleType() != 1) {
						// 开发者查询
						userId = user.getId();
					}
				} else {
					result.put("code", 10002);
					result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
					return result;
				}
			}
			List<AppApi> datalist = appApiService.listAppApisByAppId(Integer.valueOf(appId), userId);
			System.out.println("datalist = " +datalist.size() );
			list.removeIf(
					item -> !datalist.stream().anyMatch(f -> f != null && f.getApi().getId().equals(item.getId())));
		}

/*		if (apiTypeId != null) {
			list.removeIf(item -> !item.getApiType().getId().equals(apiTypeId));
		}*/
		if (null != list) {
			result.put("data", list);
			result.put("total", list.size());
			result.put("message", "查询完成");
			result.put("code", 10000);
		} else {
			result.put("code", 10001);
			result.put("total", 0);
			result.put("message", "查询成功");
		}
		return result;
	}


	@ApiOperation(value = "管理端获取接口授权列表", notes = "管理端获取接口授权列表", tags = "接口管理")
	@GetMapping(value = "/manageList")
	public Map<String, Object> manageList(HttpServletRequest request,
										  @ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag,
										  @ApiParam(value = "授权状态 0 未授权 1 已授权 2 待授权", required = false) @RequestParam(required = false) Integer accreditStatus,
										  @ApiParam(value = "能力角色id", required = false) @RequestParam(required = false) Integer roleId,
										  @ApiParam(value = "用户id", required = false) @RequestParam(required = false) Integer userId,
										  @ApiParam(value = "ApiTypeID", required = false) @RequestParam(required = false) Integer apiTypeId) {
		Map<String, Object> result = new HashMap<>();
		List<Api> list = apiService.listApiManage(tag, accreditStatus, roleId,apiTypeId,userId);
		System.out.println("list = " +list.size() );
		if (null != list) {
			result.put("data", list);
			result.put("total", list.size());
			result.put("message", "查询完成");
			result.put("code", 10000);
		} else {
			result.put("code", 10001);
			result.put("total", 0);
			result.put("message", "查询成功");
		}
		return result;
	}



	@ApiOperation(value = "获取接口列表 需要判断用户角色权限", notes = "获取接口列表", hidden = true)
	@GetMapping(value = "/listapis")
	public Map<String, Object> searchAllApis(@ApiParam(value = "能力角色id", required = false) @RequestParam(required = false) Integer roleId,
											 HttpServletRequest request) {
		Map<String, Object> result = new HashMap<>();
		String token = request.getHeader("token");
		String account = JwtHelper.parseToken(token);
		/*Integer roleId = null;
		if (null != account && account.length() > 0) {
			User user = userService.findUserByAccount(account);
			if (null != user) {
				Role role = user.getRole();
				if (null != role) {
					if (role.getRoleType() != 1) {
						roleId = role.getId();
					}
				}
			}
		}*/
		List<ApiType> types = apiTypeService.listApiTypes("");
		if (null == types) {
			result.put("code", 10001);
			result.put("message", "未配置接口类型，请联系管理员");
			return result;
		}
		List<Object> data = new ArrayList<>();

		List<String> apiTypeNames = new ArrayList<>();
		for (ApiType apiType : types) {
			Map<String, Object> map = new HashMap<>();
			List<Api> list = null;
			if(roleId != null){
				list = apiService.listApisByTypeAndRoleId(apiType.getId(),roleId);
			}else {
				list = apiService.listApisByType(apiType.getId());
			}

			map.put("name", apiType.getName());
			if (null != list && list.size() > 0) {
				List<Object> apiList = new ArrayList<>();
				for (Api api : list) {
					Map<String, Object> apiMap = new HashMap<>();
					apiMap.put("label", api.getName());
					apiMap.put("value", api.getId());
					apiList.add(apiMap);
				}
				map.put("apis", apiList);
			}
			data.add(map);
			apiTypeNames.add(apiType.getName());
		}
		result.put("code", 10000);
		result.put("data", data);
		result.put("apiTypeNames", apiTypeNames);
		result.put("total", data.size());
		result.put("message", "获取接口列表成功");

		return result;
	}

	@ApiOperation(value = "获取应用数量统计", notes = "获取应用数量统计", hidden = true)
	@GetMapping(value = "/apicount")
	public Map<String, Object> searchDevelopersReport() throws ParseException {
		Map<String, Object> result = new HashMap<>();

		result.put("allApiNum", apiService.getAllApiNum());
		result.put("publishedNum", apiService.getPublishedApiNum());
		result.put("unPublishedNum", apiService.getUnPublishedApiNum());
		SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		String beginDate = format.format(new Date()) + " 00:00:00";
		Date beginDay = sdf.parse(beginDate);
		result.put("todayCallNum", apiService.getTodayCallNum(beginDay.getTime()));
		result.put("alarmApiNum", apiService.getAlarmApiNum());
		result.put("abnormalAppNum", apiService.getAbnormalApiNum());
		result.put("message", "查询完成");
		result.put("code", 10000);

		return result;
	}

//	@ApiOperation(value = "获取能力调用排行榜", notes = "获取能力调用排行榜", hidden = true)
//	@GetMapping(value = "/topapis")
//	public Map<String, Object> searchTopDevelopers(
//			@ApiParam(value = "开始日期", required = false) @RequestParam(required = false) String beginDate,
//			@ApiParam(value = "结束日期", required = false) @RequestParam(required = false) String endDate)
//			throws ParseException {
//		Map<String, Object> result = new HashMap<>();
//		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
//		SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
//		if (null == beginDate) {
//			beginDate = format.format(new Date());
//		}
//		if (null == endDate) {
//			endDate = format.format(new Date());
//		}
//		Date beginDay = sdf.parse(beginDate + " 00:00:00");
//		Date endDay = sdf.parse(endDate + " 23:59:59");
//		Long beginTime = beginDay.getTime();
//		Long endTime = endDay.getTime();
//		List<TopApi> list = apiService.getTopTenApis(beginDate, endDate);
//		if (null != list && list.size() > 0) {
//			int i = 1;
//			List<TopApi> topApis = new ArrayList<>();
//			for (TopApi topApi : list) {
//				topApi.setId(i);
//				float num = (float) topApi.getFailCount() / topApi.getTotalCount();
//				DecimalFormat df = new DecimalFormat("0.00");
//				topApi.setFailRate(Double.parseDouble(df.format(num)));
//				i++;
//				topApis.add(topApi);
//			}
//			result.put("data", topApis);
//			result.put("total", list.size());
//			result.put("code", 10000);
//			result.put("message", "查询成功");
//		} else {
//			result.put("code", 10001);
//			result.put("message", "没有查询到结果");
//		}
//		return result;
//	}

	Boolean checkHasAdminAuth(HttpServletRequest request) {
		String token = request.getHeader("token");
		String account = "";
		if (token != null && token.length() > 0) {
			account = JwtHelper.parseToken(token);

			User user = userService.findUserByAccount(account);
			if (null != user) {
				Role role = user.getRole();
				if (role.getRoleType() == 1) {
					return true;
				}
			}
		}
		return false;
	}

	String getAccount(HttpServletRequest request) {
		String token = request.getHeader("token");
		String account = "";
		if (token != null && token.length() > 0) {
			account = JwtHelper.parseToken(token);

			User user = userService.findUserByAccount(account);
			if (null != user) {
				return user.getAccount();
			}
		}
		return "";
	}

}
