package com.ff.apimngr.controller;


import com.ff.apimngr.entity.*;
import com.ff.apimngr.jwt.JwtHelper;
import com.ff.apimngr.service.ApiLogService;
import com.ff.apimngr.service.UserService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 接口日志管理
 */
@RestController
@RequestMapping("/api/apilog")
public class ApiLogController {

    private final static Logger logger = LoggerFactory.getLogger(ApiLogController.class);

    @Resource
    private ApiLogService apiLogService;

    @Resource
    private UserService userService;

    @ApiOperation(value = "根据id获取接口日志", notes = "根据id获取接口日志",hidden = true)
    @GetMapping(value = "/findbyid")
    public Map<String, Object> getApiLogById(@ApiParam(value = "接口日志id", required = true) @RequestParam Integer id) {
        Map<String, Object> result = new HashMap<>();
        ApiLog apiLog = apiLogService.findApiLogById(id);
        if (null == apiLog) {
            result.put("code", 10001);
            result.put("message", "未查询到此接口日志");
            return result;
        }
        result.put("data", apiLog);
        result.put("code", 10000);
        result.put("message", "获取成功");
        return result;
    }

    @ApiOperation(value = "测试接口日志", notes = "测试接口日志",hidden = true)
    @PostMapping(value = "/makelog")
    public void makeLog() {
        for (int i = 0; i < 10000; i++) {
            ApiLog apiLog = new ApiLog();
            App app = new App();
            app.setId(7);
            apiLog.setApp(app);
            Api api = new Api();
            Double test = Math.random() * 100;
            int value = test.intValue() % 2;
            int check = test.intValue() % 3;
            api.setId(2 + check * 2);//
            apiLog.setApi(api);

            apiLog.setCallResult(value);
            Long now = System.currentTimeMillis() - 24 * 3600 * 1000;
            int random = test.intValue() * 1000000;
            apiLog.setInvokeTime(String.valueOf(now - random));
            apiLog.setResponseTime(String.valueOf(now - random + 2000));
            if (value == 0) {
                apiLog.setErrCode("100123");
            }
            apiLogService.insertApiLog(apiLog);
        }

    }


    @ApiOperation(value = "获取接口日志列表", notes = "获取接口日志列表",hidden = true)
    @GetMapping(value = "/list")
    public Map<String, Object> searchApiLogs(@ApiParam(value = "开始日期", required = false) @RequestParam(required = false) String beginDate,
                                             @ApiParam(value = "结束日期", required = false) @RequestParam(required = false) String endDate) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date beginDay = sdf.parse(beginDate + " 00:00:00");
        Date endDay = sdf.parse(endDate + " 23:59:59");
        List<ApiLog> list = apiLogService.listApiLogsByInvokeTime(beginDay.getTime(), endDay.getTime());
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    @ApiOperation(value = "获取概览统计数据", notes = "获取概览统计数据",hidden = true)
    @GetMapping(value = "/generalcount")
    public Map<String, Object> searchGeneralCount(@ApiParam(value = "开始日期", required = false) @RequestParam(required = false) String beginDate,
                                                  @ApiParam(value = "结束日期", required = false) @RequestParam(required = false) String endDate,
                                                  @ApiParam(value = "用户id", required = false) @RequestParam(required = false) String selectedId,
                                                  HttpServletRequest request) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        if (null == beginDate) {
            beginDate = format.format(new Date());
        }
        if (null == endDate) {
            endDate = format.format(new Date());
        }
        Date beginDay = sdf.parse(beginDate + " 00:00:00");
        Date endDay = sdf.parse(endDate + " 23:59:59");
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        Integer userId = null;
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            }
            Role role = user.getRole();
            if (null != role) {
                if (role.getRoleType() != 1) {
                    //开发者查询
                    userId = user.getId();
                } else {
                    //管理员默认查询所有数据
                    if (null != selectedId && selectedId.length() > 0) {
                        //管理员选择某个用户统计
                        try {
                            userId = Integer.parseInt(selectedId);
                        } catch (Exception e) {
                            e.printStackTrace();
                            result.put("code", 10004);
                            result.put("message", "用户id错误，请联系管理员");
                            return result;
                        }
                    }
                }
            } else {
                result.put("code", 10002);
                result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                return result;
            }
        }
        List<CountResult> list = apiLogService.selectGeneralCount(userId, beginDate, endDate);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10003);
            result.put("message", "暂无数据");
        }

        return result;
    }



    @ApiOperation(value = "获取接口监控报表-图表", notes = "获取接口监控报表-图表",hidden = true)
    @GetMapping(value = "/getreportbyapi")
    public Map<String, Object> getReportByApi(@ApiParam(value = "开始日期", required = true) @RequestParam(required = true) String beginDate,
                                              @ApiParam(value = "结束日期", required = true) @RequestParam(required = true) String endDate,
                                              @ApiParam(value = "开发者id", required = false) @RequestParam(required = false) Integer selectUser,
                                              @ApiParam(value = "应用id", required = true) @RequestParam(required = true) String appId,
                                              @ApiParam(value = "接口id", required = true) @RequestParam(required = true) String apiId,
                                              @ApiParam(value = "统计项 1=调用量 2=QPS", required = false) @RequestParam(required = false) String reportItem,
                                              @ApiParam(value = "按时/按日 1=按时 2=按日 3=实时", required = true) @RequestParam(required = true) String byHourOrDay,
                                              HttpServletRequest request) throws ParseException {
        if ("1".equals(byHourOrDay)) {
            logger.info("getReportByApi 按时统计 beginDate:" + beginDate + " endDate:" + endDate + " userId:" + selectUser + " appId:" + appId + " apiId:" + apiId);
        } else if ("2".equals(byHourOrDay)) {
            logger.info("getReportByApi 按日统计 beginDate:" + beginDate + " endDate:" + endDate + " userId:" + selectUser + " appId:" + appId + " apiId:" + apiId);
        } else if ("3".equals(byHourOrDay)) {
            logger.info("getReportByApi 实时统计 beginDate:" + beginDate + " endDate:" + endDate + " userId:" + selectUser + " appId:" + appId + " apiId:" + apiId);
        }
        Map<String, Object> result = new HashMap<>();
        List<String> categories = new ArrayList<>();
        Integer success = 0;
        Integer failed = 0;
        Integer qps = 0;
        Map<String, Object> map = new HashMap<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if ("全部".equals(apiId)) {
            apiId = "0";
        }
        Integer userId = null;
        if ("全部".equals(appId)) {
            appId = "0";
            String token = request.getHeader("token");
            String account = JwtHelper.parseToken(token);
            if (null != account && account.length() > 0) {
                User user = userService.findUserByAccount(account);
                if (null == user) {
                    result.put("code", 10001);
                    result.put("message", "接口调用失败");
                    return result;
                }
                Role role = user.getRole();
                if (null != role) {
                    if (role.getRoleType() != 1) {
                        //开发者查询
                        userId = user.getId();
                    } else {
                        if (null != selectUser) {
                            userId = selectUser;
                        }
                    }
                } else {
                    result.put("code", 10002);
                    result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                    return result;
                }
            }
        }
        if (null != reportItem && "1".equals(reportItem)) {
            //调用量查询
            if ("1".equals(byHourOrDay)) {
                //按时
                SimpleDateFormat formatDate = new SimpleDateFormat("yyyy-MM-dd HH");
                long begin = sdf.parse(beginDate + " 00:00:00").getTime();
                long end = sdf.parse(endDate + " 23:00:00").getTime();
                categories.add(beginDate + " 00:00");
                long value = begin;
                while (value < end) {
                    value += 3600 * 1000;
                    Date temp = new Date();
                    temp.setTime(value);
                    String day = formatDate.format(temp) + ":00";
                    categories.add(day);
                }

                List<Item> items = apiLogService.selectHourReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, String.valueOf(begin), String.valueOf(end));
                if (null != items) {
                    for (Item item : items) {
                        Integer successValue = item.getSuccess();
                        if (null != successValue) {
                            success += successValue;
                        }
                        Integer failedValue = item.getFailed();
                        if (null != failedValue) {
                            failed += failedValue;
                        }
                        Integer qpsValue = item.getQps();
                        if (null != qpsValue) {
                            qps += qpsValue;
                        }
                    }
                }
                List<Integer> successList = new ArrayList<>();
                List<Integer> failedList = new ArrayList<>();
                List<Integer> qpsList = new ArrayList<>();
                for (String day : categories) {
                    boolean found = false;
                    if (null != items) {
                        for (Item item : items) {
                            if (null != item.getDay() && item.getDay().equals(day)) {
                                successList.add(item.getSuccess());
                                failedList.add(item.getFailed());
                                qpsList.add(item.getQps());
                                found = true;
                                break;
                            }
                        }
                    }
                    if (!found) {
                        successList.add(0);
                        failedList.add(0);
                        qpsList.add(0);
                    }
                }

                map.put("categories", categories);
                map.put("success", success);
                map.put("failed", failed);
                map.put("qps", qps);
                map.put("successList", successList);
                map.put("failedList", failedList);
                map.put("qpsList", qpsList);

                Date beginDay = sdf.parse(beginDate + " 00:00:00");
                Date endDay = sdf.parse(endDate + " 23:59:59");
                List<FailDetail> failDetails = apiLogService.selectFailDetail(Integer.valueOf(appId), Integer.valueOf(apiId), userId, beginDay.getTime(), endDay.getTime());
                map.put("failDetais", failDetails);

            } else if ("2".equals(byHourOrDay)) {
                //按日
                long begin = sdf.parse(beginDate + " 00:00:00").getTime();
                long end = sdf.parse(endDate + " 23:59:59").getTime();
                if (beginDate.equals(endDate)) {
                    categories.add(beginDate);
                } else {
                    SimpleDateFormat formatDate = new SimpleDateFormat("yyyy-MM-dd");
                    categories.add(beginDate);
                    long value = begin;
                    long compareEnd = sdf.parse(endDate + " 00:00:00").getTime();
                    while (value < compareEnd) {
                        value += 24 * 3600 * 1000;
                        Date temp = new Date();
                        temp.setTime(value);
                        String day = formatDate.format(temp);
                        categories.add(day);
                    }
                }
                List<Item> items = apiLogService.selectDayReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, beginDate, endDate);
                if (null != items) {
                    for (Item item : items) {
                        Integer successValue = item.getSuccess();
                        if (null != successValue) {
                            success += successValue;
                        }
                        Integer failedValue = item.getFailed();
                        if (null != failedValue) {
                            failed += failedValue;
                        }
                        Integer qpsValue = item.getQps();
                        if (null != qpsValue) {
                            qps += qpsValue;
                        }
                    }
                }
                List<Integer> successList = new ArrayList<>();
                List<Integer> failedList = new ArrayList<>();
                List<Integer> qpsList = new ArrayList<>();
                for (String day : categories) {
                    boolean found = false;
                    if (null != items) {
                        for (Item item : items) {
                            if (null != item.getDay() && item.getDay().equals(day)) {
                                successList.add(item.getSuccess());
                                failedList.add(item.getFailed());
                                qpsList.add(item.getQps());
                                found = true;
                                break;
                            }
                        }
                    }
                    if (!found) {
                        successList.add(0);
                        failedList.add(0);
                        qpsList.add(0);
                    }
                }

                map.put("categories", categories);
                map.put("success", success);
                map.put("failed", failed);
                map.put("qps", qps);
                map.put("successList", successList);
                map.put("failedList", failedList);
                map.put("qpsList", qpsList);

                Date beginDay = sdf.parse(beginDate + " 00:00:00");
                Date endDay = sdf.parse(endDate + " 23:59:59");
                List<FailDetail> failDetails = apiLogService.selectFailDetail(Integer.valueOf(appId), Integer.valueOf(apiId), userId, beginDay.getTime(), endDay.getTime());
                map.put("failDetais", failDetails);

            } else if ("3".equals(byHourOrDay)) {
                //最近1分钟 60秒报表
                Date now = new Date();
                SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                long end = now.getTime();
                long begin = end - 60 * 1000;

                long value = begin;
                while (value < end) {
                    value += 1000;
                    Date temp = new Date();
                    temp.setTime(value);
                    String day = format.format(temp);
                    categories.add(day);
                }

                List<Item> items = apiLogService.selectMinuteReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, String.valueOf(begin), String.valueOf(end));
                if (null != items) {
                    for (Item item : items) {
                        Integer successValue = item.getSuccess();
                        if (null != successValue) {
                            success += successValue;
                        }
                        Integer failedValue = item.getFailed();
                        if (null != failedValue) {
                            failed += failedValue;
                        }
                        Integer qpsValue = item.getQps();
                        if (null != qpsValue) {
                            qps += qpsValue;
                        }
                    }
                }
                List<Integer> successList = new ArrayList<>();
                List<Integer> failedList = new ArrayList<>();
                List<Integer> qpsList = new ArrayList<>();
                for (String day : categories) {
                    boolean found = false;
                    if (null != items) {
                        for (Item item : items) {
                            if (null != item.getDay() && item.getDay().equals(day)) {
                                successList.add(item.getSuccess());
                                failedList.add(item.getFailed());
                                qpsList.add(item.getQps());
                                found = true;
                                break;
                            }
                        }
                    }
                    if (!found) {
                        successList.add(0);
                        failedList.add(0);
                        qpsList.add(0);
                    }
                }

                map.put("categories", categories);
                map.put("success", success);
                map.put("failed", failed);
                map.put("qps", qps);
                map.put("successList", successList);
                map.put("failedList", failedList);
                map.put("qpsList", qpsList);

                Date beginDay = sdf.parse(beginDate + " 00:00:00");
                Date endDay = sdf.parse(endDate + " 23:59:59");
                List<FailDetail> failDetails = apiLogService.selectFailDetail(Integer.valueOf(appId), Integer.valueOf(apiId), userId, begin, end);
                map.put("failDetais", failDetails);

            }


        } else if (null != reportItem && "2".equals(reportItem)) {
            //QPS查询
            List<Integer> qpsList = new ArrayList<>();
            if ("1".equals(byHourOrDay)) {
                //按时
                SimpleDateFormat formatDate = new SimpleDateFormat("yyyy-MM-dd HH");
                long begin = sdf.parse(beginDate + " 00:00:00").getTime();
                long end = sdf.parse(endDate + " 23:00:00").getTime();
                categories.add(beginDate + " 00:00");
                long value = begin;
                while (value < end) {
                    Integer rst = apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, value, value + 3600000);
                    if (null != rst) {
                        qpsList.add(rst);
                    } else {
                        qpsList.add(0);
                    }
                    value += 3600 * 1000;
                    Date temp = new Date();
                    temp.setTime(value);
                    String day = formatDate.format(temp) + ":00";
                    categories.add(day);
                }
                for (Integer temp : qpsList) {
                    if (null != temp && temp > qps) {
                        qps = temp;
                    }
                }

                map.put("qps", qps);//qps峰值
                map.put("qpsList", qpsList);
                map.put("categories", categories);

            } else if ("2".equals(byHourOrDay)) {
                //按日
                long begin = sdf.parse(beginDate + " 00:00:00").getTime();
                long end = sdf.parse(endDate + " 23:59:59").getTime();
                if (beginDate.equals(endDate)) {
                    categories.add(beginDate);
                    //qpsList.add(apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, begin, end));
                    Integer rst = apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, begin, end);
                    if (null != rst) {
                        qpsList.add(rst);
                    } else {
                        qpsList.add(0);
                    }
                } else {
                    SimpleDateFormat formatDate = new SimpleDateFormat("yyyy-MM-dd");
                    categories.add(beginDate);
                    long value = begin;
                    long compareEnd = sdf.parse(endDate + " 00:00:00").getTime();
                    while (value < compareEnd) {
                        //qpsList.add(apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, value, value + 24 * 3600 * 1000));
                        Integer rst = apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, value, value + 24 * 3600 * 1000);
                        if (null != rst) {
                            qpsList.add(rst);
                        } else {
                            qpsList.add(0);
                        }
                        value += 24 * 3600 * 1000;
                        Date temp = new Date();
                        temp.setTime(value);
                        String day = formatDate.format(temp);
                        categories.add(day);
                    }
                }
                for (Integer temp : qpsList) {
                    if (temp > qps) {
                        qps = temp;
                    }
                }

                map.put("categories", categories);
                map.put("qps", qps);
                map.put("qpsList", qpsList);

            } else if ("3".equals(byHourOrDay)) {
                //最近1分钟 60秒报表
                Date now = new Date();
                SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                long end = now.getTime();
                long begin = end - 60 * 1000;

                long value = begin;
                while (value < end) {
                    //qpsList.add(apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, value, value + 1000));
                    Integer rst = apiLogService.selectQpsReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, value, value + 1000);
                    if (null != rst) {
                        qpsList.add(rst);
                    } else {
                        qpsList.add(0);
                    }
                    value += 1000;
                    Date temp = new Date();
                    temp.setTime(value);
                    String day = format.format(temp);
                    categories.add(day);
                }

                for (Integer temp : qpsList) {
                    if (temp > qps) {
                        qps = temp;
                    }
                }
                map.put("categories", categories);
                map.put("qps", qps);
                map.put("qpsList", qpsList);

            }

        }


        result.put("data", map);
        result.put("message", "查询完成");
        result.put("code", 10000);


        return result;
    }

    @ApiOperation(value = "获取接口监控报表-报表", notes = "获取接口监控报表-报表",hidden = true)
    @GetMapping(value = "/getapireport")
    public Map<String, Object> getReportByApi2(@ApiParam(value = "开始日期", required = true) @RequestParam(required = true) String beginDate,
                                               @ApiParam(value = "结束日期", required = true) @RequestParam(required = true) String endDate,
                                               @ApiParam(value = "开发者id", required = false) @RequestParam(required = false) Integer selectUser,
                                               @ApiParam(value = "应用id", required = true) @RequestParam(required = true) String appId,
                                               @ApiParam(value = "接口id", required = true) @RequestParam(required = true) String apiId,
                                               HttpServletRequest request) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if ("全部".equals(apiId)) {
            apiId = "0";
        }
        Integer userId = null;
        if ("全部".equals(appId)) {
            appId = "0";
        }
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            }
            Role role = user.getRole();
            if (null != role) {
                if (role.getRoleType() != 1) {
                    //开发者查询
                    userId = user.getId();
                } else {
                    if (null != selectUser) {
                        userId = selectUser;
                    }
                }
            } else {
                result.put("code", 10002);
                result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                return result;
            }
        }

        //Date beginDay = sdf.parse(beginDate + " 00:00:00");
        //Date endDay = sdf.parse(endDate + " 23:59:59");
        List<ApiReport> list = apiLogService.selectApiReport(Integer.valueOf(appId), Integer.valueOf(apiId), userId, beginDate, endDate);
        if (null != list && list.size() > 0) {
            List<ApiReport> data = new ArrayList<>();
            int i = 1;
            for (ApiReport apiReport : list) {
                apiReport.setId(i);
                Integer numTotal = apiReport.getTotal();
                Integer numFail = apiReport.getFailCount();
                if (null == numTotal) {
                    apiReport.setFailRate("0%");
                } else {
                    DecimalFormat df = new DecimalFormat("0.00");
                    String value = df.format((float) numFail * 100 / numTotal);
                    apiReport.setFailRate(value + "%");
                }
                data.add(apiReport);
                i++;
            }
            result.put("code", 10000);
            result.put("message", "搜索完成");
            result.put("data", data);
            result.put("total", data.size());
        } else {
            result.put("code", 10000);
            result.put("message", "没有数据");
        }

        return result;
    }


    @ApiOperation(value = "获取开发者调用报表", notes = "获取开发者调用报表",hidden = true)
    @GetMapping(value = "/getdevreport")
    public Map<String, Object> getDeveloperReport(@ApiParam(value = "开始日期", required = true) @RequestParam(required = true) String beginDate,
                                                  @ApiParam(value = "结束日期", required = true) @RequestParam(required = true) String endDate,
                                                  HttpServletRequest request) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Integer userId = null;
        List<String> categories = new ArrayList<>();
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            } else {
                userId = user.getId();
            }
        }

        Date beginDay = sdf.parse(beginDate + " 00:00:00");
        Date endDay = sdf.parse(endDate + " 23:59:59");
        List<DeveloperReport> list = apiLogService.selectDeveloperReport(userId, beginDate, endDate);
        if (null != list && list.size() > 0) {
            List<Integer> totalList = new ArrayList<>();
            List<Integer> failList = new ArrayList<>();
            for (DeveloperReport developerReport : list) {
                totalList.add(developerReport.getTotal());
                failList.add(developerReport.getFailCount());
            }
            result.put("data", list);
            result.put("code", 10000);
            result.put("message", "搜索完成");
            result.put("total", totalList);
            result.put("fail", failList);
            for (DeveloperReport developerReport : list) {
                categories.add(developerReport.getAppName());
            }
            result.put("categories", categories);
        } else {
            result.put("code", 10000);
            result.put("message", "没有数据");
        }

        return result;
    }


    /**
     * 生成最近3个月的日表数据
     */
    @ApiOperation(value = "生成最近3个月的日表数据", hidden = true)
    @GetMapping(value = "/builddaytable")
    public void genDayTable() throws ParseException {
        apiLogService.deleteAll();
        for (int i = 0; i < 45; i++) {
            SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
            Date date = new Date();
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(date);
            calendar.add(Calendar.DAY_OF_MONTH, -45 + i);
            date = calendar.getTime();
            String day = df.format(date);
            System.out.println("===日表任务日期..." + day);
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date beginDay = sdf.parse(day + " 00:00:00");
            Date endDay = sdf.parse(day + " 23:59:59");
            long begin = beginDay.getTime();
            long end = endDay.getTime();
            apiLogService.insertToDayTable(begin, end);
        }

    }
}
