package com.ff.apimngr.controller;


import com.ff.apimngr.entity.Api;
import com.ff.apimngr.entity.ApiType;
import com.ff.apimngr.entity.Role;
import com.ff.apimngr.entity.User;
import com.ff.apimngr.jwt.JwtHelper;
import com.ff.apimngr.service.ApiService;
import com.ff.apimngr.service.ApiTypeService;
import com.ff.apimngr.service.UserService;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 能力类型管理
 */
//@io.swagger.annotations.Api(tags = "接口类型管理",position = 1)
@RestController
@RequestMapping("/api/apitype")
public class ApiTypeController {

    @Resource
    private ApiTypeService apiTypeService;

    @Resource
    private ApiService apiService;

    @Resource
    private UserService userService;

    @ApiOperation(value = "根据id获取能力类型", notes = "根据id获取能力类型",hidden = true)
    @GetMapping(value = "/findbyid")
    public Map<String, Object> getApiTypeById(@ApiParam(value = "能力类型id", required = true) @RequestParam Integer id) {
        Map<String, Object> result = new HashMap<>();
        ApiType apiType = apiTypeService.findApiTypeById(id);
        if (null == apiType) {
            result.put("code", 10001);
            result.put("message", "未查询到此能力类型");
            return result;
        }
        result.put("data", apiType);
        result.put("code", 10000);
        result.put("message", "获取成功");
        return result;
    }

    @ApiOperation(value = "根据姓名获取能力类型", notes = "根据姓名获取能力类型",hidden = true)
    @GetMapping(value = "/findbyname")
    public Map<String, Object> findApiTypeByName(@ApiParam(value = "能力类型姓名", required = true) @RequestParam String name) {
        Map<String, Object> result = new HashMap<>();
        ApiType apiType = apiTypeService.findApiTypeByName(name);
        if (null == apiType) {
            result.put("code", 10001);
            result.put("message", "未查询到此能力类型");
            return result;
        }
        result.put("data", apiType);
        result.put("code", 10000);
        result.put("message", "查询成功");
        return result;
    }

    @ApiOperation(value = "创建能力类型", notes = "创建能力类型" ,tags = "接口类型管理")
    @PostMapping(value = "/insert")
    public Map<String, Object> insertApiType(@ApiParam(value = "能力类型名字", required = true) @RequestParam String name,
                                             @ApiParam(value = "备注", required = false) @RequestParam(required = false) String description,
                                             HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        if (!checkHasAdminAuth(request)) {
            result.put("code", 10001);
            result.put("message", "没有权限");
            return result;
        }
        ApiType apiType = apiTypeService.findApiTypeByName(name);
        if (null != apiType) {
            result.put("code", 10002);
            result.put("message", "能力类型名已存在");
            return result;
        }
        apiType = new ApiType();
        apiType.setName(name);
        if(null == description) {
            apiType.setDescription("");
        } else {
            apiType.setDescription(description);
        }


        apiTypeService.insertApiType(apiType);

        result.put("code", 10000);
        result.put("message", "创建成功");
        return result;
    }

    @ApiOperation(value = "更新能力类型", notes = "更新能力类型",tags = "接口类型管理")
    @PostMapping(value = "/update")
    public Map<String, Object> updateApiType(@ApiParam(value = "能力类型id", required = true) @RequestParam String id,
                                             @ApiParam(value = "能力类型名称", required = false) @RequestParam String name,
                                             @ApiParam(value = "备注", required = false) @RequestParam(required = false) String description,
                                             HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        if (!checkHasAdminAuth(request)) {
            result.put("code", 10001);
            result.put("message", "没有权限");
            return result;
        }
        ApiType apiType = apiTypeService.findApiTypeById(Integer.valueOf(id));
        if (null == apiType) {
            result.put("code", 10001);
            result.put("message", "能力类型不存在");
            return result;
        }
        ApiType check = apiTypeService.findApiTypeByName(name);
        if (check != null && check.getId() != Integer.valueOf(id)) {
            result.put("code", 10001);
            result.put("message", "能力类型名称已存在,不可重复");
            return result;
        }
        apiType.setName(name);
        apiType.setDescription(description);

        boolean rst = apiTypeService.updateApiType(apiType);
        result.put("code", 10000);
        result.put("message", "更新成功");
        return result;
    }


    @ApiOperation(value = "根据id删除能力类型", notes = "根据id删除能力类型" ,tags = "接口类型管理")
    @PostMapping(value = "/delete")
    public Map<String, Object> deleteApiType(@ApiParam(value = "能力类型id", required = true) @RequestParam String id,
                                             HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        if (!checkHasAdminAuth(request)) {
            result.put("code", 10001);
            result.put("message", "没有权限");
            return result;
        }
        ApiType apiType = apiTypeService.findApiTypeById(Integer.valueOf(id));
        if (null == apiType) {
            result.put("code", 10001);
            result.put("message", "删除失败，能力类型不存在");
            return result;
        }
        List<Api> list = apiService.listApisByType(apiType.getId());
        if (null != list && list.size() > 0) {
            result.put("code", 10003);
            result.put("message", "无法删除，能力正在正在使用此能力类型");
            return result;
        }
        boolean rst = apiTypeService.deleteApiTypeById(Integer.valueOf(id));
        if (rst) {
            result.put("code", 10000);
            result.put("message", "删除成功");
        } else {
            result.put("code", 10002);
            result.put("message", "删除失败");
        }

        return result;
    }

    @ApiOperation(value = "获取能力类型列表", notes = "获取能力类型列表",tags = "接口类型管理")
    @GetMapping(value = "/list")
    public Map<String, Object> searchApiTypes(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag) {
        Map<String, Object> result = new HashMap<>();
        List<ApiType> list = apiTypeService.listApiTypes(tag);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    Boolean checkHasAdminAuth(HttpServletRequest request) {
        String token = request.getHeader("token");
        String account = "";
        if (token != null && token.length() > 0) {
            account = JwtHelper.parseToken(token);

            User user = userService.findUserByAccount(account);
            if (null != user) {
                Role role = user.getRole();
                if (role.getRoleType() == 1) {
                    return true;
                }
            }
        }
        return false;
    }
}
