package com.ff.apimngr.controller;


import com.ff.apimngr.entity.*;
import com.ff.apimngr.jwt.JwtHelper;
import com.ff.apimngr.service.*;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 应用接口管理 /接口权限
 */
@RestController
@RequestMapping("/api/appapi")
public class AppApiController {

    @Resource
    private AppApiService appApiService;

    @Resource
    private QpsApplyService qpsApplyService;

    @Resource
    private UserService userService;

    @Resource
    private AppService appService;

    @Resource
    private ApiService apiService;

    @ApiOperation(value = "根据id获取接口权限", notes = "根据id获取接口权限",hidden = true)
    @GetMapping(value = "/findbyid")
    public Map<String, Object> getAppApiById(@ApiParam(value = "接口权限id", required = true) @RequestParam Integer id) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiById(id);
        if (null == appApi) {
            result.put("code", 10001);
            result.put("message", "未查询到此接口权限");
            return result;
        }
        result.put("data", appApi);
        result.put("code", 10000);
        result.put("message", "获取成功");
        return result;
    }

    @ApiOperation(value = "根据姓名获取接口权限", notes = "根据姓名获取接口权限",hidden = true)
    @GetMapping(value = "/findbyname")
    public Map<String, Object> findAppApiByName(@ApiParam(value = "接口权限姓名", required = true) @RequestParam String name) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiByName(name);
        if (null == appApi) {
            result.put("code", 10001);
            result.put("message", "未查询到此接口权限");
            return result;
        }
        result.put("data", appApi);
        result.put("code", 10000);
        result.put("message", "查询成功");
        return result;
    }

    /*@ApiOperation(value = "创建接口权限", notes = "创建接口权限")
    @PostMapping(value = "/insert")
    public Map<String, Object> insertAppApi(@ApiParam(value = "接口权限名字", required = true) @RequestParam String name,
                                          @ApiParam(value = "备注", required = false) @RequestParam(required = false) String description) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiByName(name);
        if(null != appApi) {
            result.put("code",10002);
            result.put("message","接口权限名已存在");
            return result;
        }
        appApi = new AppApi();
        appApi.setName(name);
        if(null != description && description.length() > 0) {
            appApi.setDescription(description);
        }
        appApiService.insertAppApi(appApi);

        result.put("code", 10000);
        result.put("message", "创建成功");
        return result;
    }*/

    @ApiOperation(value = "更新接口权限", notes = "更新接口权限",tags = "app接口管理")
    @PostMapping(value = "/update")
    public Map<String, Object> updateAppApi(@ApiParam(value = "接口权限id", required = true) @RequestParam String id,
                                            @ApiParam(value = "调用限制", required = false) @RequestParam(required = false) String callLimit,
                                            @ApiParam(value = "QPS限制", required = false) @RequestParam(required = false) String qpsLimit) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiById(Integer.valueOf(id));
        if (null == appApi) {
            result.put("code", 10001);
            result.put("message", "接口权限不存在");
            return result;
        }
        appApi.setCallLimit(callLimit);
        appApi.setQpsLimit(qpsLimit);

        appApiService.updateAppApi(appApi);
        result.put("code", 10000);
        result.put("message", "更新成功");
        return result;
    }


    @ApiOperation(value = "根据id删除接口权限", notes = "根据id删除接口权限",tags = "app接口管理")
    @PostMapping(value = "/delete")
    public Map<String, Object> deleteAppApi(@ApiParam(value = "接口权限id", required = true) @RequestParam String id) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiById(Integer.valueOf(id));
        if (null == appApi) {
            result.put("code", 10001);
            result.put("message", "删除失败，接口权限不存在");
            return result;
        }
        boolean rst = appApiService.deleteAppApiById(Integer.valueOf(id));
        if (rst) {
            result.put("code", 10000);
            result.put("message", "删除成功");
        } else {
            result.put("code", 10002);
            result.put("message", "删除失败");
        }

        return result;
    }

    @ApiOperation(value = "获取接口权限列表", notes = "获取接口权限列表",tags = "app接口管理")
    @GetMapping(value = "/list")
    public Map<String, Object> searchAppApis(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag) {
        Map<String, Object> result = new HashMap<>();
        List<AppApi> list = appApiService.listAppApis(tag);
        if (null != list) {
            for (AppApi appApi : list) {
                App app = appApi.getApp();
                app = appService.findAppById(app.getId());
                appApi.setApp(app);
            }
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }


    @ApiOperation(value = "应用详情获取选中接口列表", notes = "应用详情获取选中接口列表",tags = "app接口管理")
    @GetMapping(value = "/getCheckApiList")
    public Map<String, Object> getCheckApiList(@ApiParam(value = "搜索关键字", required = true) @RequestParam(required = true) Integer appId) {
        Map<String, Object> result = new HashMap<>();
        List<Integer> list = appApiService.getCheckApiList(appId);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }
        return result;
    }

    @ApiOperation(value = "应用详情提交接口使用申请", notes = "应用详情提交接口使用申请",tags = "app接口管理")
    @PostMapping(value = "/addAppApi")
    public Map<String, Object> addAppApi(@ApiParam(value = "id", required = false) @RequestParam(required = false) Integer id,
                                         @ApiParam(value = "appId", required = true) @RequestParam Integer appId,
                                         @ApiParam(value = "apiId", required = true) @RequestParam Integer apiId,
                                         @ApiParam(value = "调用量限制", required = true) @RequestParam String callLimit,
                                         @ApiParam(value = "QPS限制", required = true) @RequestParam String qpsLimit) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = new AppApi();
        App appById = appService.findAppById(appId);
        Api apiById = apiService.findApiById(apiId);
        if (null == appById) {
            result.put("code", 10001);
            result.put("message", "应用信息不存在");
            return result;
        }
        if (null == apiById) {
            result.put("code", 10001);
            result.put("message", "接口信息不存在");
            return result;
        }
        if(id == null) {
            appApi.setApp(appById);
            appApi.setApi(apiById);
            appApi.setCallLimit(callLimit);
            appApi.setQpsLimit(qpsLimit);
            appApi.setStatus(0);
            appApi.setEnable(0);
            appApiService.insertAppApi(appApi);
        }else {
            AppApi appApiById = appApiService.findAppApiById(id);
            if(appApiById != null){
                appApiById.setStatus(0);
                appApiService.updateAppApi(appApiById);
            }
        }
        result.put("code", 10000);
        result.put("message", "接口使用申请提交成功");
        return result;
    }


    @ApiOperation(value = "管理端审核应用申请接口使用状态", notes = "管理端审核应用申请接口使用状态",tags = "app接口管理")
    @PostMapping(value = "/editAppApiStatus")
    public Map<String, Object> editAppApiStatus(@ApiParam(value = "appId", required = true) @RequestParam Integer appApiId,
                                                @ApiParam(value = "status 1 通过 2 驳回", required = true) @RequestParam Integer status) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApiById = appApiService.findAppApiById(appApiId);
        if(appApiById != null){
            App appById = appService.findAppById(appApiById.getApp().getId());
            if(appById != null && appById.getStatus() != 1){
                result.put("code", 10005);
                result.put("message", "只有正常状态的应用才可以审核");
                return result;
            }
        }
        if(appApiById != null && appApiById.getStatus() == 0){
            appApiById.setStatus(status);
            boolean b = appApiService.updateAppApi(appApiById);
            if(b){
                result.put("code", 10000);
                result.put("message", "审核成功");
                return result;
            }
        }
        result.put("code", 10003);
        result.put("message", "该数据不满足审核条件");
        return result;
    }


    @ApiOperation(value = "管理端启用/停用 开发者接口使用状态", notes = "管理端启用/停用 开发者接口使用状态",tags = "app接口管理")
    @PostMapping(value = "/editAppApiEnable")
    public Map<String, Object> editAppApiEnable(@ApiParam(value = "appId", required = true) @RequestParam Integer appApiId,
                                                @ApiParam(value = "enable 0 启用 1停用", required = true) @RequestParam Integer enable) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApiById = appApiService.findAppApiById(appApiId);
        if(appApiById != null){
            appApiById.setEnable(enable);
            boolean b = appApiService.updateAppApi(appApiById);
            if(b){
                result.put("code", 10000);
                result.put("message", "审核成功");
                return result;
            }
        }
        result.put("code", 10003);
        result.put("message", "该数据不满足审核条件");
        return result;
    }


    @ApiOperation(value = "根据id停用/启动应用的接口权限", notes = "根据id停用/启动应用的接口权限",tags = "app接口管理")
    @PostMapping(value = "/disable")
    public Map<String, Object> disableApi(@ApiParam(value = "接口权限id", required = true) @RequestParam String id,
                                          @ApiParam(value = "停用/启用接口权限", required = true) @RequestParam Integer status) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiById(Integer.valueOf(id));
        if (null == appApi) {
            result.put("code", 10001);
            result.put("message", "更新失败，接口权限不存在");
            return result;
        }
        appApi.setStatus(status);
        appApiService.updateAppApi(appApi);
        result.put("code", 10000);
        result.put("message", "停用启用应用接口权限成功");

        return result;
    }

    @ApiOperation(value = "根据appId获取接口权限列表(管理端)", notes = "根据appId获取接口权限列表",tags = "app接口管理")
    @GetMapping(value = "/listbyappid")
    public Map<String, Object> searchAppApisByAppId(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String appId, HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        Integer userId = null;
        if (null != appId && "全部".equals(appId)) {
            appId = "0";
        }
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            }
            Role role = user.getRole();
            if (null != role) {
                if (role.getRoleType() != 1) {
                    //开发者查询
                    userId = user.getId();
                }
            } else {
                result.put("code", 10002);
                result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                return result;
            }
        }
        List<AppApi> list = appApiService.listAppApisByAppId(Integer.valueOf(appId), userId);
        if (null != list && list.size() > 0) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询失败");
        }

        return result;
    }


    @ApiOperation(value = "根据appId获取接口权限列表(开发者端)", notes = "根据appId获取接口权限列表",tags = "app接口管理")
    @GetMapping(value = "/listbyappidDev")
    public Map<String, Object> listbyappidDev(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String appId, HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        Integer userId = null;
        if (null != appId && "全部".equals(appId)) {
            appId = "0";
        }
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            }
            Role role = user.getRole();
            if (null != role) {
                if (role.getRoleType() != 1) {
                    //开发者查询
                    userId = user.getId();
                }
            } else {
                result.put("code", 10002);
                result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                return result;
            }
        }
        List<AppApi> list = appApiService.listAppApisByAppIdDev(Integer.valueOf(appId), userId);
        if (null != list && list.size() > 0) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询失败");
        }

        return result;
    }


    @ApiOperation(value = "当应用选择全部的时候，获取所有接口列表", notes = "当应用选择全部的时候，获取所有接口列表",tags = "app接口管理")
    @GetMapping(value = "/getmyallapis")
    public Map<String, Object> getMyAllApis(HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        Integer userId = null;
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            }
            Role role = user.getRole();
            if (null != role) {
                if (role.getRoleType() != 1) {
                    //开发者查询
                    userId = user.getId();
                }
            } else {
                result.put("code", 10002);
                result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                return result;
            }
        }
        List<AppApi> list = appApiService.listAllMyApis(userId);
        if (null != list && list.size() > 0) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询失败");
        }

        return result;
    }

    @ApiOperation(value = "根据appApiId申请更高QPS", notes = "根据appApiId申请更高QPS",hidden = true,tags = "app接口管理")
    @PostMapping(value = "/addapplyqps")
    public Map<String, Object> deleteAppApi(@ApiParam(value = "接口权限id", required = true) @RequestParam String appApiId,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String maxQps,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String callTimes,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String areas,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String companyName,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String phone,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String email,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String description,
                                            @ApiParam(value = "接口权限id", required = true) @RequestParam String applyReason) {
        Map<String, Object> result = new HashMap<>();
        AppApi appApi = appApiService.findAppApiById(Integer.valueOf(appApiId));
        if (null == appApi) {
            result.put("code", 10001);
            result.put("message", "删除失败，接口权限不存在");
            return result;
        }
        QpsApply qpsApply = new QpsApply();
        qpsApply.setMaxQps(maxQps);
        qpsApply.setCallTimes(callTimes);
        qpsApply.setAreas(areas);
        qpsApply.setCompanyName(companyName);
        qpsApply.setPhone(phone);
        qpsApply.setEmail(email);
        qpsApply.setDescription(description);
        qpsApply.setApplyReason(applyReason);
        qpsApply.setApplyStatus(2);//申请状态 0=默认配额 1=已审核 2=审核中 3=已拒绝
        qpsApplyService.insertQpsApply(qpsApply);
        appApi.setQpsApply(qpsApply);
        appApiService.updateAppApi(appApi);
        result.put("code", 10000);
        result.put("message", "申请成功");
        return result;
    }


    @ApiOperation(value = "根据appId获取接口权限列表", notes = "根据appId获取接口权限列表",tags = "app接口管理",hidden = true)
    @GetMapping(value = "/listqpsapply")
    public Map<String, Object> searchQpsApplyByStatus(@ApiParam(value = "更高QPS申请状态", required = false) @RequestParam(required = false) Integer status) {
        Map<String, Object> result = new HashMap<>();
        List<HashMap> list = qpsApplyService.listQpsApplyByTag(status);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询失败");
        }

        return result;
    }

    @ApiOperation(value = "根据appApiId申请更高QPS", notes = "根据appApiId申请更高QPS",tags = "app接口管理",hidden = true)
    @PostMapping(value = "/approveqps")
    public Map<String, Object> approveApi(@ApiParam(value = "接口权限id", required = true) @RequestParam String qpsId,
                                          @ApiParam(value = "审批结果", required = true) @RequestParam Integer status) {
        Map<String, Object> result = new HashMap<>();
        QpsApply qpsApply = qpsApplyService.findQpsApplyById(Integer.valueOf(qpsId));
        if (null == qpsApply) {
            result.put("code", 10001);
            result.put("message", "审批失败，接口权限不存在");
            return result;
        }
        qpsApply.setApplyStatus(status);
        qpsApplyService.updateQpsApply(qpsApply);
        result.put("code", 10000);
        result.put("message", "审批成功");
        return result;
    }


    @ApiOperation(value = "获取概览可用服务列表", notes = "获取概览可用服务列表",tags = "app接口管理",hidden = true)
    @GetMapping(value = "/listservice")
    public Map<String, Object> searchGeneralCount(@ApiParam(value = "用户id", required = false) @RequestParam(required = false) String selectedId,
                                                  HttpServletRequest request) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        Integer userId = null;
        if (null != account && account.length() > 0) {
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10001);
                result.put("message", "接口调用失败");
                return result;
            }
            Role role = user.getRole();
            if (null != role) {
                if (role.getRoleType() != 1) {
                    //开发者查询
                    userId = user.getId();
                } else {
                    //管理员默认查询所有数据
                    if (null != selectedId && selectedId.length() > 0) {
                        //管理员选择某个用户统计
                        try {
                            userId = Integer.parseInt(selectedId);
                        } catch (Exception e) {
                            e.printStackTrace();
                            result.put("code", 10004);
                            result.put("message", "用户id错误，请联系管理员");
                            return result;
                        }
                    }
                }
            } else {
                result.put("code", 10002);
                result.put("message", "用户角色获取失败，请重新登录或者联系管理员");
                return result;
            }
        }
        List<GeneralService> list = appApiService.selectGeneralService(userId);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10003);
            result.put("message", "暂无数据");
        }

        return result;
    }

    @ApiOperation(value = "获取应用的接口剩余调用次数", notes = "获取应用的接口剩余调用次数",tags = "app接口管理",hidden = true)
    @GetMapping(value = "/selecttimes")
    public Map<String, Object> searchTimes(@ApiParam(value = "用户id", required = true) @RequestParam(required = true) String appId,
                                           HttpServletRequest request) throws ParseException {
        Map<String, Object> result = new HashMap<>();

        List<SelectTimes> list = appApiService.selectTimes(Integer.valueOf(appId));
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10003);
            result.put("message", "暂无数据");
        }

        return result;
    }

    @ApiOperation(value = "获取开发者应用的接口剩余调用次数", notes = "获取开发者应用的接口剩余调用次数",tags = "app接口管理",hidden = true)
    @GetMapping(value = "/selectusertimes")
    public Map<String, Object> searchUserTimes(@ApiParam(value = "用户id", required = true) @RequestParam(required = true) String userId,
                                           HttpServletRequest request) throws ParseException {
        Map<String, Object> result = new HashMap<>();

        List<SelectUserTimes> list = appApiService.selectUserTimes(Integer.valueOf(userId));
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10003);
            result.put("message", "暂无数据");
        }

        return result;
    }
}
