package com.ff.apimngr.controller;


import com.ff.apimngr.entity.AppType;
import com.ff.apimngr.entity.Role;
import com.ff.apimngr.entity.User;
import com.ff.apimngr.jwt.JwtHelper;
import com.ff.apimngr.service.AppTypeService;
import com.ff.apimngr.service.UserService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 应用类型管理
 */
//@Api(tags = "app类型管理" ,description = "")
@RestController
@RequestMapping("/api/apptype")
public class AppTypeController {

    @Resource
    private AppTypeService appTypeService;

    @Resource
    private UserService userService;

    @ApiOperation(value = "根据id获取接口类型", notes = "根据id获取接口类型",hidden = true)
    @GetMapping(value = "/findbyid")
    public Map<String, Object> getAppTypeById(@ApiParam(value = "接口类型id", required = true) @RequestParam Integer id) {
        Map<String, Object> result = new HashMap<>();
        AppType appType = appTypeService.findAppTypeById(id);
        if (null == appType) {
            result.put("code", 10001);
            result.put("message", "未查询到此接口类型");
            return result;
        }
        result.put("data", appType);
        result.put("code", 10000);
        result.put("message", "获取成功");
        return result;
    }

    @ApiOperation(value = "根据姓名获取接口类型", notes = "根据姓名获取接口类型",hidden = true)
    @GetMapping(value = "/findbyname")
    public Map<String, Object> findAppTypeByName(@ApiParam(value = "接口类型姓名", required = true) @RequestParam String name) {
        Map<String, Object> result = new HashMap<>();
        AppType appType = appTypeService.findAppTypeByName(name);
        if (null == appType) {
            result.put("code", 10001);
            result.put("message", "未查询到此接口类型");
            return result;
        }
        result.put("data", appType);
        result.put("code", 10000);
        result.put("message", "查询成功");
        return result;
    }

    @ApiOperation(value = "创建接口类型", notes = "创建接口类型",tags = "app管理")
    @PostMapping(value = "/insert")
    public Map<String, Object> insertAppType(@ApiParam(value = "接口类型名字", required = true) @RequestParam String name,
                                             @ApiParam(value = "备注", required = false) @RequestParam(required = false) String description,
                                             HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        if (!checkHasAdminAuth(request)) {
            result.put("code", 10001);
            result.put("message", "没有权限");
            return result;
        }
        AppType appType = appTypeService.findAppTypeByName(name);
        if (null != appType) {
            result.put("code", 10002);
            result.put("message", "接口类型名已存在");
            return result;
        }
        appType = new AppType();
        appType.setName(name);
        if(null == description) {
            appType.setDescription("");
        } else {
            appType.setDescription(description);
        }


        appTypeService.insertAppType(appType);

        result.put("code", 10000);
        result.put("message", "创建成功");
        return result;
    }

    @ApiOperation(value = "更新接口类型", notes = "更新接口类型",tags = "app管理")
    @PostMapping(value = "/update")
    public Map<String, Object> updateAppType(@ApiParam(value = "接口类型id", required = true) @RequestParam String id,
                                             @ApiParam(value = "接口类型姓名", required = false) @RequestParam String name,
                                             @ApiParam(value = "备注", required = false) @RequestParam(required = false) String description,
                                             HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        if (!checkHasAdminAuth(request)) {
            result.put("code", 10001);
            result.put("message", "没有权限");
            return result;
        }
        AppType appType = appTypeService.findAppTypeById(Integer.valueOf(id));
        if (null == appType) {
            result.put("code", 10001);
            result.put("message", "接口类型不存在");
            return result;
        }
        AppType check = appTypeService.findAppTypeByName(name);
        if (null != check && check.getId() != appType.getId()) {
            result.put("code", 10002);
            result.put("message", "接口类型名已存在");
            return result;
        }

        appType.setName(name);
        appType.setDescription(description);


        boolean rst = appTypeService.updateAppType(appType);
        result.put("code", 10000);
        result.put("message", "更新成功");
        return result;
    }


    @ApiOperation(value = "根据id删除接口类型", notes = "根据id删除接口类型",tags = "app管理")
    @PostMapping(value = "/delete")
    public Map<String, Object> deleteAppType(@ApiParam(value = "接口类型id", required = true) @RequestParam String id,
                                             HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        if (!checkHasAdminAuth(request)) {
            result.put("code", 10001);
            result.put("message", "没有权限");
            return result;
        }
        AppType appType = appTypeService.findAppTypeById(Integer.valueOf(id));
        if (null == appType) {
            result.put("code", 10001);
            result.put("message", "删除失败，接口类型不存在");
            return result;
        }
        boolean rst = appTypeService.deleteAppTypeById(Integer.valueOf(id));
        if (rst) {
            result.put("code", 10000);
            result.put("message", "删除成功");
        } else {
            result.put("code", 10002);
            result.put("message", "删除失败");
        }

        return result;
    }

    @ApiOperation(value = "获取接口类型列表", notes = "获取接口类型列表",tags = "app管理")
    @GetMapping(value = "/list")
    public Map<String, Object> searchAppTypes(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag) {
        Map<String, Object> result = new HashMap<>();
        List<AppType> list = appTypeService.listAppTypes(tag);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    Boolean checkHasAdminAuth(HttpServletRequest request) {
        String token = request.getHeader("token");
        String account = "";
        if (token != null && token.length() > 0) {
            account = JwtHelper.parseToken(token);

            User user = userService.findUserByAccount(account);
            if (null != user) {
                Role role = user.getRole();
                if (role.getRoleType() == 1) {
                    return true;
                }
            }
        }
        return false;
    }
}
