package com.ff.apimngr.controller;


import com.ff.apimngr.entity.CodeInfo;
import com.ff.apimngr.service.CodeInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 错误码信息管理
 */
@Api(hidden = true)
@RestController
@RequestMapping("/api/codeinfo")
public class CodeInfoController {

    @Resource
    private CodeInfoService codeInfoService;

    @ApiOperation(value = "创建错误码", notes = "创建错误码")
    @PostMapping(value = "/insert")
    public Map<String, Object> insertApi(@ApiParam(value = "错误码", required = true) @RequestParam String errorCode,
                                         @ApiParam(value = "错误描述", required = true) @RequestParam String description,
                                         @ApiParam(value = "错误详情", required = true) @RequestParam String message,
                                         @ApiParam(value = "处理意见", required = true) @RequestParam String suggestion) {
        Map<String, Object> result = new HashMap<>();
        CodeInfo codeInfo = codeInfoService.findCodeInfoByCode(errorCode);
        if (null != codeInfo) {
            result.put("code", 10002);
            result.put("message", "错误码已存在");
            return result;
        }
        codeInfo = new CodeInfo();
        codeInfo.setErrorCode(errorCode);
        codeInfo.setDescription(description);
        codeInfo.setMessage(message);
        codeInfo.setSuggestion(suggestion);

        codeInfoService.insertCodeInfo(codeInfo);

        result.put("code", 10000);
        result.put("message", "创建成功");
        return result;
    }

    @ApiOperation(value = "更新接口", notes = "更新接口")
    @PostMapping(value = "/update")
    public Map<String, Object> updateApi(@ApiParam(value = "错误码", required = true) @RequestParam String errorCode,
                                         @ApiParam(value = "错误描述", required = true) @RequestParam String description,
                                         @ApiParam(value = "错误详情", required = true) @RequestParam String message,
                                         @ApiParam(value = "处理意见", required = true) @RequestParam String suggestion) {
        Map<String, Object> result = new HashMap<>();
        CodeInfo codeInfo = codeInfoService.findCodeInfoByCode(errorCode);
        if (null == codeInfo) {
            result.put("code", 10002);
            result.put("message", "错误码不存在");
            return result;
        }
        codeInfo.setDescription(description);
        codeInfo.setMessage(message);
        codeInfo.setSuggestion(suggestion);

        codeInfoService.updateCodeInfo(codeInfo);

        result.put("code", 10000);
        result.put("message", "更新成功");
        return result;
    }


    @ApiOperation(value = "根据code获取错误码信息", notes = "根据code获取错误码信息")
    @GetMapping(value = "/findbycode")
    public Map<String, Object> getCodeInfoByCode(@ApiParam(value = "错误码信息code", required = true) @RequestParam String errorCode) {
        Map<String, Object> result = new HashMap<>();
        CodeInfo codeInfo = codeInfoService.findCodeInfoByCode(errorCode);
        if (null == codeInfo) {
            result.put("code", 10001);
            result.put("message", "未查询到此错误码信息");
            return result;
        }
        result.put("data", codeInfo);
        result.put("code", 10000);
        result.put("message", "获取成功");
        return result;
    }


    @ApiOperation(value = "根据code删除错误码信息", notes = "根据code删除错误码信息")
    @PostMapping(value = "/delete")
    public Map<String, Object> deleteCodeInfo(@ApiParam(value = "错误码信息code", required = true) @RequestParam String errorCode) {
        Map<String, Object> result = new HashMap<>();
        CodeInfo codeInfo = codeInfoService.findCodeInfoByCode(errorCode);
        if (null == codeInfo) {
            result.put("code", 10001);
            result.put("message", "删除失败，错误码信息不存在");
            return result;
        }
        boolean rst = codeInfoService.deleteCodeInfoByCode(errorCode);
        if (rst) {
            result.put("code", 10000);
            result.put("message", "删除成功");
        } else {
            result.put("code", 10002);
            result.put("message", "删除失败");
        }

        return result;
    }

    @ApiOperation(value = "获取错误码信息列表", notes = "获取错误码信息列表")
    @GetMapping(value = "/list")
    public Map<String, Object> searchList(@ApiParam(value = "模糊搜索错误码", required = false) @RequestParam String tag) {
        Map<String, Object> result = new HashMap<>();
        List<CodeInfo> list = codeInfoService.list(tag);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }
}
