package com.ff.apimngr.controller;


import com.alibaba.druid.util.StringUtils;
import com.ff.apimngr.entity.*;
import com.ff.apimngr.jwt.JwtHelper;
import com.ff.apimngr.service.RoleService;
import com.ff.apimngr.service.SmsLogService;
import com.ff.apimngr.service.SystemLogService;
import com.ff.apimngr.service.UserService;
import com.ff.apimngr.util.GraphicCode;
import com.ff.apimngr.util.RandomValidateCodeUtil;
import com.ff.apimngr.util.RedisUtil;
import com.ff.apimngr.util.SendMsmUtils;
import com.google.code.kaptcha.Producer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.FastByteArrayOutputStream;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * 开发者账号管理
 */
@Api(hidden = true)
@RestController
@RequestMapping("/api/user")
@Slf4j
public class UserController {

    @Resource
    private UserService userService;

    @Resource
    private RoleService roleService;

    @Resource
    private SystemLogService systemLogService;

    @Resource
    private SmsLogService smsLogService;

    @Resource
    private RedisUtil redisUtil;

    @Resource(name = "captchaProducer")
    private Producer captchaProducer;

    @ApiOperation(value = "根据id获取用户", notes = "根据id获取用户")
    @GetMapping(value = "/findbyid")
    public Map<String, Object> getUserById(@ApiParam(value = "用户id", required = true) @RequestParam Integer id) {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserById(id);
        if (null == user) {
            result.put("code", 10001);
            result.put("message", "未查询到此用户");
            return result;
        }
        result.put("data", user);
        result.put("code", 10000);
        result.put("message", "获取成功");
        return result;
    }

    @ApiOperation(value = "根据姓名获取用户", notes = "根据姓名获取用户")
    @GetMapping(value = "/findbyname")
    public Map<String, Object> findUserByName(@ApiParam(value = "用户姓名", required = true) @RequestParam String name) {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserByName(name);
        if (null == user) {
            result.put("code", 10001);
            result.put("message", "未查询到此用户");
            return result;
        }
        result.put("data", user);
        result.put("code", 10000);
        result.put("message", "查询成功");
        return result;
    }

    @ApiOperation(value = "发送验证码短信", notes = "发送验证码短信")
    @PostMapping(value = "/getsms")
    public Map<String, Object> getRegisterSms(@ApiParam(value = "用户手机号", required = true) @RequestParam String phone,
                                              @ApiParam(value = "图形验证码", required = true) @RequestParam String gcode,
                                              HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        HttpSession session = request.getSession();
        String validCode = (String) session.getAttribute("code");
        if (null == gcode || !gcode.equalsIgnoreCase(validCode)) {
            result.put("code", 10002);
            result.put("message", "图形验证码错误");
            return result;
        }
        //检查已发送几条
        Date now = new Date();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String nowDate = sdf.format(now);
        String beginTime = nowDate + " 00:00:00";
        String endTime = nowDate + " 23:59:59";
        Integer count = smsLogService.listCount(phone, beginTime, endTime);
        if (count >= 5) {
            result.put("code", 10001);
            result.put("message", "今日短信发送条数已达上限");
            return result;
        }
        //SmsLog smsLog = smsLogService.findSmsLogByPhone(phone);
        String code = String.valueOf((int) ((Math.random() * 9 + 1) * 100000));
        SendMsmUtils.sendMsm(phone, code);
        SmsLog smsLog = new SmsLog();
        smsLog.setPhone(phone);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        smsLog.setCreateTime(format.format(now));
        smsLog.setCode(code);
        smsLog.setStatus(1);
        smsLogService.insertSmsLog(smsLog);
        result.put("code", 10000);
        result.put("message", "短信验证码发送成功");
        return result;
    }

    @ApiOperation(value = "发送密码验证码短信", notes = "发送密码验证码短信")
    @PostMapping(value = "/getpwsms")
    public Map<String, Object> getPwSms(@ApiParam(value = "用户手机号", required = true) @RequestParam String phone,
                                        @ApiParam(value = "图形验证码", required = true) @RequestParam String gcode,
                                        HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        HttpSession session = request.getSession();
        String validCode = (String) session.getAttribute("code");
        if (null == gcode || !gcode.equalsIgnoreCase(validCode)) {
            result.put("code", 10002);
            result.put("message", "图形验证码错误");
            return result;
        }
        User user = userService.findUserByPhone(phone);
        if (null == user) {
            result.put("code", 10001);
            result.put("message", "此手机尚未注册，无法找回密码");
            return result;
        }
        //检查已发送几条
        Date now = new Date();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String nowDate = sdf.format(now);
        String beginTime = nowDate + " 00:00:00";
        String endTime = nowDate + " 23:59:59";
        Integer count = smsLogService.listCount(phone, beginTime, endTime);
        if (count >= 5) {
            result.put("code", 10001);
            result.put("message", "今日短信发送条数已达上限");
            return result;
        }
        String code = String.valueOf((int) ((Math.random() * 9 + 1) * 100000));
        SendMsmUtils.sendMsm(phone, code);
        SmsLog smsLog = new SmsLog();
        smsLog.setPhone(phone);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        smsLog.setCreateTime(format.format(now));
        smsLog.setCode(code);
        smsLog.setStatus(1);
        smsLogService.insertSmsLog(smsLog);
        result.put("code", 10000);
        result.put("message", "短信验证码发送成功");
        return result;
    }

    @PostMapping("/checkvalidcode")
    @ApiOperation(value = "找回密码短信验证", notes = "找回密码短信验证")
    public Map<String, Object> checkValidCode(@ApiParam(required = true, value = "手机号码") @RequestParam String phone,
                                              @ApiParam(required = true, value = "短信验证码") @RequestParam String pwValidCode,
                                              HttpServletRequest request) throws Exception {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserByPhone(phone);
        if (null == user) {
            result.put("code", 10003);
            result.put("message", "用户不存在");
            return result;
        }
        SmsLog smsLog = smsLogService.findSmsLogByPhone(phone);
        if (null == smsLog) {
            result.put("code", 10001);
            result.put("message", "验证码已过期");
            return result;
        }
        if (null != smsLog) {
            String createTime = smsLog.getCreateTime();
            Calendar c = Calendar.getInstance();
            c.setTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(createTime));
            Long createTimeValue = c.getTimeInMillis();
            Long now = System.currentTimeMillis();
            if (now - createTimeValue > 5 * 60 * 1000) {
                smsLog.setStatus(0);
                smsLogService.updateSmsLog(smsLog);
                result.put("code", 10002);
                result.put("message", "验证码已过期");
                return result;
            }
        }
        if (!smsLog.getCode().equals(pwValidCode)) {
            result.put("code", 10002);
            result.put("message", "验证码错误/已过期");
            return result;
        }
        smsLog.setStatus(0);
        smsLogService.updateSmsLog(smsLog);
        result.put("code", 10000);
        result.put("message", "验证通过");
        return result;
    }

    @PostMapping("/resetpw")
    @ApiOperation(value = "开发者找回密码/修改密码", notes = "开发者找回密码/修改密码")
    public Map<String, Object> resetPassword(@ApiParam(required = true, value = "手机号码") @RequestParam String phone,
                                             @ApiParam(required = true, value = "新密码") @RequestParam String resetPw,
                                             HttpServletRequest request) throws Exception {
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserByPhone(phone);
        if (null == user) {
            result.put("code", 10003);
            result.put("message", "用户不存在");
            return result;
        }
        if (!user.getAccount().equals(account)) {
            result.put("code", 10002);
            result.put("message", "系统错误");
            return result;
        }
        user.setPassword(resetPw);
        userService.updateUser(user);

        result.put("code", 10000);
        result.put("message", "密码已重置，请重新登录");
        return result;
    }

    /*@PostMapping("/resetpw")
    @ApiOperation(value = "开发者找回密码/修改密码", notes = "开发者找回密码/修改密码")
    public Map<String, Object> resetPassword(@ApiParam(required = true, value = "手机号码") @RequestParam String phone,
                                             @ApiParam(required = true, value = "短信验证码") @RequestParam String pwValidCode,
                                             @ApiParam(required = true, value = "新密码") @RequestParam String resetPw,
                                             HttpServletRequest request) throws Exception {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserByPhone(phone);
        if (null == user) {
            result.put("code", 10003);
            result.put("message", "用户不存在");
            return result;
        }
        SmsLog smsLog = smsLogService.findSmsLogByPhone(phone);
        if (null == smsLog) {
            result.put("code", 10001);
            result.put("message", "验证码已过期");
            return result;
        }
        if (!smsLog.getCode().equals(pwValidCode)) {
            result.put("code", 10002);
            result.put("message", "验证码错误/已过期");
            return result;
        }
        user.setPassword(resetPw);
        userService.updateUser(user);
        smsLog.setStatus(0);
        smsLogService.updateSmsLog(smsLog);
        result.put("code", 10000);
        result.put("message", "密码已重置，请重新登录");
        return result;
    }*/

    @ApiOperation(value = "创建用户", notes = "创建用户")
    @PostMapping(value = "/insert")
    public Map<String, Object> insertUser(@ApiParam(value = "用户姓名", required = true) @RequestParam String name,
                                          @ApiParam(value = "用户账号", required = true) @RequestParam String account,
                                          @ApiParam(value = "电话", required = true) @RequestParam String phone,
                                          @ApiParam(value = "验证码", required = true) @RequestParam String validCode,
                                          @ApiParam(value = "用户密码", required = true) @RequestParam String password,
                                          @ApiParam(value = "email", required = true) @RequestParam String email,
                                          @ApiParam(value = "角色id", required = false) @RequestParam(required = false) String roleId,
                                          @ApiParam(value = "公司名称", required = false) @RequestParam(required = false) String companyName,
                                          @ApiParam(value = "公司介绍", required = false) @RequestParam(required = false) String companyInfo) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        //测试跳过验证
        SmsLog smsLog = null;
        if (null != validCode && "123456".equals(validCode)) {
            //fixme 20190524
        } else {
            smsLog = smsLogService.findSmsLogByPhone(phone);
            if (null == smsLog) {
                result.put("code", 10001);
                result.put("message", "验证码错误");
                return result;
            }
            if (null != smsLog) {
                String createTime = smsLog.getCreateTime();
                Calendar c = Calendar.getInstance();
                c.setTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(createTime));
                Long createTimeValue = c.getTimeInMillis();
                Long now = System.currentTimeMillis();
                if (now - createTimeValue > 5 * 60 * 1000) {
                    smsLog.setStatus(0);
                    smsLogService.updateSmsLog(smsLog);
                    result.put("code", 10002);
                    result.put("message", "验证码已过期");
                    return result;
                }
            }
            if (!smsLog.getCode().equals(validCode)) {
                result.put("code", 10003);
                result.put("message", "验证码错误");
                return result;
            }
        }

        User user = userService.findUserByAccount(account);
        if (null != user) {
            result.put("code", 10002);
            result.put("message", "帐号名已存在");
            return result;
        }
        user = userService.findUserByPhone(phone);
        if (null != user) {
            result.put("code", 10004);
            result.put("message", "手机号已被注册");
            return result;
        }
        user = new User();
        user.setName(name);
        user.setAccount(account);
        user.setPassword(password);
        user.setPhone(phone);
        user.setEmail(email);
        user.setStatus(1);//默认账号状态 = 普通用户
        if (null == roleId || (null != roleId && roleId.length() == 0)) {
            user.setRole(roleService.findRoleById(2));//注册为开发者
        } else {
            user.setRole(roleService.findRoleById(Integer.valueOf(roleId)));
        }
        if (null != companyName && companyName.length() > 0) {
            user.setCompanyName(companyName);
        }
        if (null != companyInfo && companyInfo.length() > 0) {
            user.setCompanyInfo(companyInfo);
        }

        userService.insertUser(user);
        if (null != validCode && "123456".equals(validCode)) {
            //
        } else {
            smsLog.setStatus(0);
            smsLogService.updateSmsLog(smsLog);
        }

        result.put("code", 10000);
        result.put("message", "帐号注册成功，请登录");
        return result;
    }

    @ApiOperation(value = "管理员添加开发者", notes = "管理员添加开发者")
    @PostMapping(value = "/insertbyadmin")
    public Map<String, Object> insertUserByAdmin(@ApiParam(value = "用户姓名", required = true) @RequestParam String name,
                                                 @ApiParam(value = "用户账号", required = true) @RequestParam String account,
                                                 @ApiParam(value = "电话", required = true) @RequestParam String phone,
                                                 @ApiParam(value = "用户密码", required = true) @RequestParam String password,
                                                 @ApiParam(value = "email", required = true) @RequestParam String email,
                                                 @ApiParam(value = "用户状态", required = true) @RequestParam(required = false) String status,
                                                 @ApiParam(value = "公司名称", required = false) @RequestParam(required = false) String companyName,
                                                 @ApiParam(value = "公司介绍", required = false) @RequestParam(required = false) String companyInfo) {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserByAccount(account);
        if (null != user) {
            result.put("code", 10002);
            result.put("message", "帐号名已存在");
            return result;
        }
        user = userService.findUserByPhone(phone);
        if (null != user) {
            result.put("code", 10004);
            result.put("message", "手机号已被注册");
            return result;
        }
        user = new User();
        user.setName(name);
        user.setAccount(account);
        user.setPassword(password);
        user.setPhone(phone);
        user.setEmail(email);
        if (null != status && status.length() > 0) {
            user.setStatus(Integer.valueOf(status));
        } else {
            user.setStatus(1);//默认账号状态 = 免费用户
        }


        user.setRole(roleService.findRoleById(2));//注册为开发者

        if (null != companyName && companyName.length() > 0) {
            user.setCompanyName(companyName);
        } else {
            user.setCompanyName("");
        }
        if (null != companyInfo && companyInfo.length() > 0) {
            user.setCompanyInfo(companyInfo);
        } else {
            user.setCompanyInfo("");
        }

        userService.insertUser(user);

        result.put("code", 10000);
        result.put("message", "帐号添加成功");
        return result;
    }

    @ApiOperation(value = "更新用户", notes = "更新用户")
    @PostMapping(value = "/update")
    public Map<String, Object> updateUser(@ApiParam(value = "用户id", required = true) @RequestParam String id,
                                          @ApiParam(value = "用户姓名", required = false) @RequestParam(required = false) String name,
                                          @ApiParam(value = "用户账号", required = false) @RequestParam(required = false) String account,
                                          @ApiParam(value = "电话", required = false) @RequestParam(required = false) String phone,
                                          @ApiParam(value = "用户密码", required = false) @RequestParam(required = false) String password,
                                          @ApiParam(value = "email", required = false) @RequestParam(required = false) String email,
                                          @ApiParam(value = "用户状态", required = false) @RequestParam(required = false) Integer status,
                                          @ApiParam(value = "角色id", required = false) @RequestParam(required = false) String roleId,
                                          @ApiParam(value = "公司名称", required = false) @RequestParam(required = false) String companyName,
                                          @ApiParam(value = "公司介绍", required = false) @RequestParam(required = false) String companyInfo) {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserById(Integer.valueOf(id));
        if (null == user) {
            result.put("code", 10001);
            result.put("message", "用户不存在");
            return result;
        }
        if (!StringUtils.isEmpty(name)) {
            user.setName(name);
        }
        if (!StringUtils.isEmpty(account)) {
            user.setAccount(account);
        }
        if (!StringUtils.isEmpty(password)) {
            user.setPassword(password);
        }
        user.setPhone(phone);
        user.setEmail(email);
        if (null != roleId) {
            Role role = roleService.findRoleById(Integer.valueOf(roleId));
            if (null != role) {
                user.setRole(role);
            }
        }

        if (!StringUtils.isEmpty(roleId)) {
            user.setRole(roleService.findRoleById(Integer.valueOf(roleId)));
        }

        user.setCompanyName(companyName);
        user.setCompanyInfo(companyInfo);


        user.setStatus(status);

        boolean rst = userService.updateUser(user);
        result.put("code", 10000);
        result.put("message", "更新成功");
        return result;
    }


    @ApiOperation(value = "根据id删除用户", notes = "根据id删除用户")
    @PostMapping(value = "/delete")
    public Map<String, Object> deleteUser(@ApiParam(value = "用户id", required = true) @RequestParam String id) {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserById(Integer.valueOf(id));
        if (null == user) {
            result.put("code", 10001);
            result.put("message", "删除失败，用户不存在");
            return result;
        }
        boolean rst = userService.deleteUserById(Integer.valueOf(id));
        if (rst) {
            result.put("code", 10000);
            result.put("message", "删除成功");
        } else {
            result.put("code", 10002);
            result.put("message", "删除失败");
        }

        return result;
    }

    @ApiOperation(value = "获取用户列表", notes = "获取用户列表")
    @GetMapping(value = "/list")
    public Map<String, Object> searchUsers(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag,
                                           @ApiParam(value = "用户状态", required = false) @RequestParam(required = false) Integer status,
                                           @ApiParam(value = "用户角色", required = false) @RequestParam(required = false) Integer roleType) {
        Map<String, Object> result = new HashMap<>();
        List<User> list = userService.listUsers(tag, status, roleType);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    @ApiOperation(value = "获取开发者列表", notes = "获取开发者列表")
    @GetMapping(value = "/listdevelopers")
    public Map<String, Object> searchAllDevelopers() {
        Map<String, Object> result = new HashMap<>();
        List<User> list = userService.listAllDevelopers();
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    @ApiOperation(value = "获取开发者数量统计", notes = "获取开发者数量统计")
    @GetMapping(value = "/developercount")
    public Map<String, Object> searchDevelopersReport() throws ParseException {
        Map<String, Object> result = new HashMap<>();
        Long begin = System.currentTimeMillis();
        result.put("allNum", userService.getAllNum());
        System.out.println("step 1: " + (System.currentTimeMillis() - begin));
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String beginDate = format.format(new Date()) + " 00:00:00";
        Date beginDay = sdf.parse(beginDate);
        result.put("todayActiveNum", userService.getTodayActiveNum(String.valueOf(beginDay.getTime())));
        System.out.println("step 2: " + (System.currentTimeMillis() - begin));

        Calendar cale = Calendar.getInstance();
        // 获取前月的第一天
        cale.add(Calendar.MONTH, 0);
        cale.set(Calendar.DAY_OF_MONTH, 1);
        Date monthDay = sdf.parse(format.format(cale.getTime()) + " 00:00:00");
        result.put("monthAcitveNum", userService.getTodayActiveNum(String.valueOf(monthDay.getTime())));
        System.out.println("step 3: " + (System.currentTimeMillis() - begin));
        result.put("alaramNum", userService.getAlarmNum());
        System.out.println("step 4: " + (System.currentTimeMillis() - begin));
        result.put("abnormalNum", userService.getAbnormalNum());
        System.out.println("step 5: " + (System.currentTimeMillis() - begin));
        result.put("illegalNum", userService.getIllegalNum());
        System.out.println("step 6: " + (System.currentTimeMillis() - begin));
        result.put("message", "查询完成");
        result.put("code", 10000);


        return result;
    }

    @ApiOperation(value = "获取开发者活跃排行榜", notes = "获取开发者活跃排行榜")
    @GetMapping(value = "/topdevelopers")
    public Map<String, Object> searchTopDevelopers(@ApiParam(value = "开始日期", required = false) @RequestParam(required = false) String beginDate,
                                                   @ApiParam(value = "结束日期", required = false) @RequestParam(required = false) String endDate) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        if (null == beginDate) {
            beginDate = format.format(new Date());
        }
        if (null == endDate) {
            endDate = format.format(new Date());
        }
        Date beginDay = sdf.parse(beginDate + " 00:00:00");
        Date endDay = sdf.parse(endDate + " 23:59:59");
        Long beginTime = beginDay.getTime();
        Long endTime = endDay.getTime();
        List<TopDeveloper> list = userService.getTopTenDevelopers(beginDate, endDate);
        if (null != list && list.size() > 0) {
            int i = 1;
            List<TopDeveloper> topDevelopers = new ArrayList<>();
            for (TopDeveloper topDeveloper : list) {
                topDeveloper.setId(i);
                i++;
                topDevelopers.add(topDeveloper);
            }
            result.put("data", topDevelopers);
            result.put("total", list.size());
            result.put("code", 10000);
            result.put("message", "查询成功");
        } else {
            result.put("code", 10001);
            result.put("message", "没有查询到结果");
        }
        return result;
    }

    @ApiOperation(value = "根据id审核开发者", notes = "根据id审核开发者")
    @PostMapping(value = "/approve")
    public Map<String, Object> approveApp(@ApiParam(value = "应用id", required = true) @RequestParam String id,
                                          @ApiParam(value = "审批结果", required = true) @RequestParam Integer status) {
        Map<String, Object> result = new HashMap<>();
        User user = userService.findUserById(Integer.valueOf(id));
        if (null == user) {
            result.put("code", 10001);
            result.put("message", "审批失败，开发者不存在");
            return result;
        }
        user.setStatus(status);
        userService.updateUser(user);
        result.put("code", 10000);
        result.put("message", "审核成功");

        return result;
    }

    @ApiOperation(value = "获取开发者列表", notes = "获取开发者列表")
    @GetMapping(value = "/listdev")
    public Map<String, Object> searchDevlopers(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag,
                                               @ApiParam(value = "用户状态", required = false) @RequestParam(required = false) Integer status) {
        Map<String, Object> result = new HashMap<>();
        List<User> list = userService.listUsers(tag, status, 2);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    @ApiOperation(value = "管理员开发者列表界面获取开发者列表", notes = "管理员开发者列表界面获取开发者列表")
    @GetMapping(value = "/listdevbyadmin")
    public Map<String, Object> searchDevlopers(@ApiParam(value = "搜索关键字", required = false) @RequestParam(required = false) String tag,
                                               @ApiParam(value = "使用频率状态 1=今日 2=本周 3=本月", required = false) @RequestParam(required = false) Integer callValue,
                                               @ApiParam(value = "活跃状态 1=活跃账户 2=不活跃账户 30天有接口调用记录的为活跃用户，否则为不活跃账号", required = false) @RequestParam(required = false) Integer statusValue,
                                               @ApiParam(value = "预警状态 1=预警账户 2=异常账户 3=非法账户  调用次数剩余20%用户为预警用户", required = false) @RequestParam(required = false) Integer alarmValue) throws ParseException {
        Map<String, Object> result = new HashMap<>();
        List<User> list = userService.listUsersByAdmin(tag, callValue, statusValue, alarmValue, 2);
        if (null != list) {
            result.put("data", list);
            result.put("total", list.size());
            result.put("message", "查询完成");
            result.put("code", 10000);
        } else {
            result.put("code", 10001);
            result.put("total", 0);
            result.put("message", "查询成功");
        }

        return result;
    }

    @PostMapping("/login")
    @ApiOperation(value = "用户登录接口", notes = "用户登录")
    public Map<String, Object> loginUser(@ApiParam(required = true, value = "登录帐号") @RequestParam String account,
                                         @ApiParam(required = true, value = "登录密码") @RequestParam String password,
                                         @ApiParam(required = true, value = "验证码") @RequestParam String code,
                                         @ApiParam(required = true, value = "uuid") @RequestParam String uuid,
                                         HttpServletRequest request) throws Exception {
        Map<String, Object> result = new HashMap<>();
        //HttpSession session = request.getSession();
        //String validCode = (String) session.getAttribute("code");
        if (StringUtils.isEmpty(code) || StringUtils.isEmpty(uuid)) {
            result.put("code", 10002);
            result.put("message", "验证码错误");
            return result;
        }
        String validCode = (String) redisUtil.get(uuid);
/*        if (null == code || !code.equalsIgnoreCase(validCode)) {
            validCode = (String) redisUtil.get(account);
            if (!code.equalsIgnoreCase(validCode)) {
                result.put("code", 10002);
                result.put("message", "验证码错误");
                return result;
            }
        }*/
        redisUtil.del(uuid);
        if (!code.equalsIgnoreCase(validCode)) {
            result.put("code", 10002);
            result.put("message", "验证码错误");
            return result;
        }

        User user = userService.findUserByAccount(account);
        if (null != user) {
            if (user.getPassword().equals(password)) {
                if (user.getStatus() == 0) {
                    result.put("code", 10003);
                    result.put("message", "帐号异常，请联系管理员");
                    return result;
                }
                result.put("code", 10000);
                result.put("message", "登录成功");
                //记录日志
                SystemLog systemLog = new SystemLog();
                systemLog.setLogAccount(account);
                systemLog.setLogContent(request.getServletPath());
                systemLog.setLogIp(getRemoteIP(request));
                Date now = new Date();
                SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                systemLog.setLogTime(format.format(now));
                systemLogService.insertSystemLog(systemLog);

                Map<String, Object> data = new HashMap<String, Object>();
                data.put("token", JwtHelper.generateToken(account));
                result.put("data", data);
            } else {
                result.put("code", 10001);
                result.put("message", "账号或密码错误");
            }
        } else {
            user = userService.findUserByPhone(account);
            if (null != user) {
                if (user.getPassword().equals(password)) {
                    if (user.getStatus() == 0) {
                        result.put("code", 10003);
                        result.put("message", "帐号异常，请联系管理员");
                        return result;
                    }
                    result.put("code", 10000);
                    result.put("message", "登录成功");
                    //记录日志
                    SystemLog systemLog = new SystemLog();
                    systemLog.setLogAccount(user.getAccount());
                    systemLog.setLogContent(request.getServletPath());
                    systemLog.setLogIp(getRemoteIP(request));
                    Date now = new Date();
                    SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                    systemLog.setLogTime(format.format(now));
                    systemLogService.insertSystemLog(systemLog);

                    Map<String, Object> data = new HashMap<String, Object>();
                    data.put("token", JwtHelper.generateToken(user.getAccount()));
                    result.put("data", data);
                } else {
                    result.put("code", 10001);
                    result.put("message", "账号或密码错误");
                }
            } else {
                result.put("code", 10002);
                result.put("message", "账号或密码错误");
            }

        }
        return result;
    }

    /**
     * 生成验证码
     */
    @GetMapping(value = "/getverify")
    @ApiOperation(value = "生成验证码", notes = "生成验证码")
    public void getVerify(HttpServletRequest request, HttpServletResponse response) {
        try {
            response.setContentType("image/jpeg");//设置相应类型,告诉浏览器输出的内容为图片
            response.setHeader("Pragma", "No-cache");//设置响应头信息，告诉浏览器不要缓存此内容
            response.setHeader("Cache-Control", "no-cache");
            response.setDateHeader("Expire", 0);
            RandomValidateCodeUtil randomValidateCode = new RandomValidateCodeUtil();
            randomValidateCode.getRandcode(request, response);//输出验证码图片方法
        } catch (Exception e) {
            System.out.println("获取验证码失败>>>>   ");
        }
    }

    @PostMapping(value = "/checkverify")
    @ApiOperation(value = "验证验证码", notes = "验证验证码")
    public Map<String, Object> checkVerify(@ApiParam(required = true, value = "图形验证码") @RequestParam String imgCode,
                                           HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        try {
            //从session中获取随机数
            String random = (String) request.getSession().getAttribute("RANDOMVALIDATECODEKEY");
            if (random == null) {
                result.put("code", 10001);
                result.put("message", "验证码已失效");
            }
            if (random.equals(imgCode)) {
                result.put("code", 10000);
                result.put("message", "验证码验证成功");
            } else {
                result.put("code", 10002);
                result.put("message", "图形验证码错误");
            }
        } catch (Exception e) {
            System.out.println("验证码校验失败");
            result.put("code", 10002);
            result.put("message", "图形验证码错误");
        }
        return result;
    }

    @PostMapping("/logout")
    @ApiOperation(value = "用户退出接口", notes = "用户退出")
    public Map<String, Object> loginUser(HttpServletRequest request) throws Exception {
        Map<String, Object> result = new HashMap<>();
        //HttpSession httpSession = request.getSession();
        //httpSession.removeAttribute("loginUser");
        result.put("code", 10000);
        return result;
    }

    @PostMapping("/changepw")
    @ApiOperation(value = "用户修改密码接口", notes = "修改密码")
    public Map<String, Object> changePassword(@ApiParam(required = true, value = "旧密码") @RequestParam String oldpassword,
                                              @ApiParam(required = true, value = "新密码") @RequestParam String newpassword,
                                              HttpServletRequest request) throws Exception {
        Map<String, Object> result = new HashMap<>();
        String token = request.getHeader("token");
        String account = JwtHelper.parseToken(token);
        User user = userService.findUserByAccount(account);
        if (null != user && null != oldpassword) {
            if (user.getPassword().equals(oldpassword)) {
                user.setPassword(newpassword);
                userService.updateUser(user);
                result.put("message", "密码修改完成");
                result.put("code", 10000);
            } else {
                result.put("code", 10001);
                result.put("message", "旧密码验证失败");
            }

        } else {
            result.put("code", 10001);
            result.put("message", "修改密码失败");
        }

        return result;
    }

    @GetMapping("/info")
    @ApiOperation(value = "用户信息获取", notes = "获取登录用户信息")
    public Map<String, Object> getInfo(@ApiParam(required = false, value = "登录帐号") @RequestParam(required = false) String account,
                                       HttpServletRequest request) {
        Map<String, Object> result = new HashMap<>();
        String token = request.getHeader("token");
        if (null != token) {
            account = JwtHelper.parseToken(token);
            User user = userService.findUserByAccount(account);
            if (null == user) {
                result.put("code", 10003);
                result.put("message", "用户不存在");
                return result;
            }
            Map<String, Object> data = new HashMap<String, Object>();
            List<String> roles = new ArrayList<String>();
            Role role = user.getRole();
            if (null != role) {
                int roleType = role.getRoleType();
                //1=管理员 2=开发者 3=vip开发者
                if (roleType == 1) {
                    //roles.add("admin");
                    roles.add("1");
                } else if (roleType == 2) {
                    roles.add("2");
                } else if (roleType == 3) {
                    roles.add("3");
                }
            }
            //roles.add("admin");
            data.put("roles", roles);
            data.put("roleId", role.getId());
            data.put("userId", user.getId());
            data.put("roleType", role.getRoleType());
            data.put("name", user.getName());
            result.put("code", 10000);
            result.put("data", data);
        } else {
            result.put("code", 10002);
            result.put("message", "用户不存在");
        }

        return result;

    }

    @PostMapping("/activteuser")
    @ApiOperation(value = "封号/解封用户", notes = "封号/解封用户")
    public Map<String, Object> actviateUser(@ApiParam(required = true, value = "帐号") @RequestParam String account,
                                            @ApiParam(required = true, value = "封号/解封") @RequestParam Integer status) {
        Map<String, Object> result = new HashMap<>();
        if ("admin".equals(account)) {
            result.put("code", 10002);
            result.put("message", "操作无效！");
            return result;
        }
        User user = userService.findUserByAccount(account);
        if (null != user) {
            user.setStatus(status);
            userService.updateUser(user);
            result.put("code", 10000);
            result.put("message", "操作成功");
        } else {
            result.put("code", 10001);
            result.put("message", "此用户不存在");
        }
        return result;
    }


    /**
     * 生成验证码
     */
    @GetMapping("/captchaImage")
    public Map<String, Object> getCode(HttpServletResponse response) throws IOException {
        Map<String, Object> result = new HashMap<>();
        // 保存验证码信息
        String uuid = UUID.randomUUID().toString().replaceAll("-", "");

        String code = null;
        BufferedImage image = null;

        // 生成验证码
        code = captchaProducer.createText();
        image = captchaProducer.createImage(code);

        redisUtil.set(uuid, code);
        redisUtil.expire(uuid, 300000);//300秒,5分钟过期
        // 转换流信息写出
        FastByteArrayOutputStream os = new FastByteArrayOutputStream();
        try {
            ImageIO.write(image, "jpg", os);
        } catch (IOException e) {
            result.put("code", 10001);
            result.put("message", "生成验证码失败");
            return result;
        }

        result.put("uuid", uuid);
        result.put("img", com.ff.apimngr.util.Base64.encode(os.toByteArray()));
        result.put("code", 10000);
        result.put("message", "操作成功");
        return result;
    }

    @GetMapping("/gencode")
    @ApiOperation(value = "生成验证码", notes = "生成验证码")
    public Map<String, Object> genCode(HttpServletRequest request, HttpServletResponse response) throws Exception {
        //Map<String, Object> result = new HashMap<>();
        // 设置响应的类型格式为图片格式
        response.setContentType("image/jpeg");
        //禁止图像缓存。
        response.setHeader("Pragma", "no-cache");
        response.setHeader("Cache-Control", "no-cache");
        response.setDateHeader("Expires", 0);
        response.setHeader("Access-Control-Expose-Headers", "key");
        //String key = UUID.randomUUID().toString().replace("_", "").replace("-", "");
        //result.put("key", key);
        HttpSession session = request.getSession();
        GraphicCode vCode = new GraphicCode(150, 36, 4, 50);
        session.setAttribute("code", vCode.getCode());
        vCode.write(response.getOutputStream());
        System.out.println(vCode.getCode());
        String queryString = request.getQueryString();
        if (!StringUtils.isEmpty(queryString) && queryString.contains("username")) {
            String userName = queryString.substring(9, 14);
            redisUtil.set(userName, vCode.getCode());
            redisUtil.expire(userName, 300000);//300秒,5分钟过期
        }
        return null;

        //ByteArrayOutputStream baos = new ByteArrayOutputStream();
        //ImageIO.write(vCode.getBuffImg(), "jpg", baos);
        //result.put("data", new BASE64Encoder().encodeBuffer( baos.toByteArray()).trim());
    }

    public String getRemoteIP(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("X-Real-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

}
