package com.ff.apimngr.dao;

import com.ff.apimngr.entity.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;


@Mapper
public interface ApiLogMapper {


    /**
     * 根据id查找
     *
     * @param id
     * @return
     */
    ApiLog findById(Integer id);

    /**
     * 插入
     *
     * @param apiLog
     * @return
     */
    boolean insert(ApiLog apiLog);

    /**
     * 更新
     *
     * @param apiLog
     * @return
     */
    boolean update(ApiLog apiLog);

    /**
     * 根据id删除
     *
     * @param id
     * @return
     */
    boolean deleteById(Integer id);


    /**
     * 根据调用日期搜索接口列表，只返回状态=1的接口
     *
     * @param beginDate 开始日期
     * @param endDate   结束日期
     * @return
     */
    List<ApiLog> listApiLogsByInvokeTime(@Param("beginDate") Long beginDate, @Param("endDate") Long endDate);

    /**
     * 获取概览页面数据接口
     *
     * @param userId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<CountResult> selectGeneralCount(@Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);

    /**
     * 获取接口监控报表
     *
     * @param appId
     * @param apiId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<CountResult> getApiCallReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("beginDate") Long beginDate, @Param("endDate") Long endDate, @Param("monitorSuccess") Boolean monitorSuccess, @Param("monitorFail") Boolean monitorFail);

    CountResult getApiCallNum(@Param("appIds") List<Integer> appIds, @Param("apiIds") List<Integer> apiIds, @Param("userIds") List<Integer> userIds,@Param("type") Integer type);

    /**
     * 获取接口监控报表
     *
     * @param appId
     * @param apiId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<CountResult> getApiQpsReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("beginDate") Long beginDate, @Param("endDate") Long endDate);

    /**
     * 根据日期生成 appId， apiId,sucess,failed记录
     *
     * @param beginDate
     * @param endDate
     */
    void insertToDayTable(@Param("beginDate") Long beginDate, @Param("endDate") Long endDate);

    void insertToHourTable(@Param("beginDate") Long beginDate, @Param("endDate") Long endDate);

    /**
     * 按天 根据appid，apiid和日期查询
     *
     * @param appId
     * @param apiId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<Item> selectDayReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);


    /**
     * 按小时 根据appid，apiid和日期查询
     *
     * @param appId
     * @param apiId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<Item> selectHourReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);

    /**
     * 按分，根据appid，apiid和日期查询
     *
     * @param appId
     * @param apiId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<Item> selectMinuteReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);

    /**
     * 查询某一段时间的qps
     * @param appId
     * @param apiId
     * @param userId
     * @param beginDate
     * @param endDate
     * @return
     */
    Integer selectQpsReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") long beginDate, @Param("endDate") long endDate);

    /**
     * 根据appid，apiid和日期，查询失败详情（汇总）
     *
     * @param appId
     * @param apiId
     * @param beginDate
     * @param endDate
     * @return
     */
    List<FailDetail> selectFailDetail(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") Long beginDate, @Param("endDate") Long endDate);

    List<FailDetail> selectFailDetailDay(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);

    List<ApiReport> selectApiReport(@Param("appId") Integer appId, @Param("apiId") Integer apiId, @Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);

    List<DeveloperReport> selectDeveloperReport(@Param("userId") Integer userId, @Param("beginDate") String beginDate, @Param("endDate") String endDate);

    void deleteAll();

    List<CountResult> getRealTimeCallToday (@Param("appIds") List<Integer> appIds, @Param("apiIds") List<Integer> apiIds, @Param("userIds") List<Integer> userIds);
    List<CountResult> getRealTimeCallWeek (@Param("appIds") List<Integer> appIds, @Param("apiIds") List<Integer> apiIds, @Param("userIds") List<Integer> userIds);
    List<CountResult> getRealTimeCallMonth (@Param("appIds") List<Integer> appIds, @Param("apiIds") List<Integer> apiIds, @Param("userIds") List<Integer> userIds);
    List<CountResult> getRegion (@Param("appIds") List<Integer> appIds, @Param("apiIds") List<Integer> apiIds, @Param("userIds") List<Integer> userIds,@Param("type") String type);
}
