package com.ff.apimngr.dao;

import com.ff.apimngr.entity.Api;
import com.ff.apimngr.entity.ApplyVO;
import com.ff.apimngr.entity.ExamineVO;
import com.ff.apimngr.entity.TopApi;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

import java.util.List;


@Mapper
public interface ApiMapper {


    /**
     * 根据id查找
     *
     * @param id
     * @return
     */
    Api findById(Integer id);

    /**
     * 根据姓名查找
     *
     * @param name
     * @return
     */
    Api findByName(String name);

    /**
     * 插入
     *
     * @param api
     * @return
     */
    boolean insert(Api api);

    /**
     * 更新
     *
     * @param api
     * @return
     */
    boolean update(Api api);

    /**
     * 根据id删除
     *
     * @param id
     * @return
     */
    boolean deleteById(Integer id);

    /**
     * 根据tag搜索列表
     *
     * @param tag
     * @return
     */
    List<Api> listApis(@Param("tag") String tag, Integer status,@Param("apiTypeId") Integer apiTypeId);

    /**
     * 根据tag搜索列表
     *
     * @param tag
     * @return
     */
    List<Api> listApi(@Param("tag") String tag, @Param("accreditStatus")Integer accreditStatus, @Param("status") Integer status, @Param("roleId") Integer roleId,@Param("apiTypeId") Integer apiTypeId);

    /**
     * 根据apiTypeId搜索接口列表
     *
     * @param apiTypeId
     * @return
     */
    List<Api> listApisByType(@Param("apiTypeId") Integer apiTypeId);
    List<Api> listApisByTypeAndRoleId(@Param("apiTypeId") Integer apiTypeId,@Param("roleId")  Integer roleId);


    int getAllApiNum();
    int getApplyNum(@Param("userIds") List<Integer> userIds);

    int getPublishedApiNum();
    int getUnPublishedApiNum();
    int getTodayCallNum(@Param("startTime") Long startTime);
    int getAlarmApiNum();
    int getAbnormalApiNum();
    List<TopApi> getTopTenApis(@Param("appIds") List<Integer> appIds, @Param("apiIds") List<Integer> apiIds, @Param("userIds") List<Integer> userIds,@Param("type")Integer type);
    
    @Update("update t_api set browser_count = browser_count + 1 where api_id = #{value}")
    int incrBrowserCount(Integer id);
    @Select("select count(*) from t_api_log where api_id = #{value}")
    int getInvokeApiNum(Integer id);
    @Select("select count(*) from t_api_collect where api_id = #{value}")
    int getCollectApiNum(Integer id);

    List<ApplyVO> getApplyList(@Param("userId")Integer userId, @Param("apiName")String apiName, @Param("apiType")Integer apiType);

    List<ExamineVO> getExamineList(@Param("status")Integer status, @Param("userName")String userName);

    List<Api> listApiManage(@Param("tag") String tag, @Param("accreditStatus")Integer accreditStatus, @Param("roleId") Integer roleId,@Param("apiTypeId") Integer apiTypeId,@Param("userId") Integer userId);

}
