package com.ff.apimngr.service;

import com.ff.apimngr.dao.UserMapper;
import com.ff.apimngr.entity.TopDeveloper;
import com.ff.apimngr.entity.User;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

@Service
public class UserService {

    @Resource
    private UserMapper userMapper;

    public User findUserById(Integer id) {
        return userMapper.findUserById(id);
    }

    public User findUserByName(String name) {
        return userMapper.findUserByName(name);
    }

    public User findUserByAccount(String account) {
        return userMapper.findUserByAccount(account);
    }

    public User findUserByPhone(String phone) {
        return userMapper.findUserByPhone(phone);
    }

    public boolean insertUser(User user) {
        return userMapper.insertUser(user);
    }

    public boolean updateUser(User user) {
        return userMapper.updateUser(user);
    }

    public boolean deleteUserById(Integer id) {
        return userMapper.deleteUserById(id);
    }

    public List<User> listUsers(String tag, Integer status, Integer roleType) {
        return userMapper.listUsers(tag, status, roleType);
    }

    public List<User> listAllDevelopers() {
        return userMapper.listAllDevelopers();
    }

    public int getAllNum() {
        return userMapper.getAllNum();
    }

    public int getTodayActiveNum(String startTime) {
        return userMapper.getTodayActiveNum(startTime);
    }

    public int getMonthActiveNum(Long startTime) {
        return userMapper.getMonthActiveNum(startTime);
    }

    public int getAlarmNum() {
        return userMapper.getAlarmNum();
    }

    public int getAbnormalNum() {
        return userMapper.getAbnormalNum();
    }

    public int getIllegalNum() {
        return userMapper.getIllegalNum();
    }

    public List<TopDeveloper> getTopTenDevelopers(String startDate, String endDate) {
        return userMapper.getTopTenDevelopers(startDate, endDate);
    }

    public List<User> listUsersByAdmin(String tag, Integer callValue, Integer statusValue, Integer alarmValue, Integer roleType) throws ParseException {
        Long startTime = 0L;
        Long endTime = System.currentTimeMillis();
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        if (null != callValue) {
            if (callValue == 1) {
                //当日
                String today = format.format(new Date()) + " 00:00:00";
                startTime = sdf.parse(today).getTime();
            } else if (callValue == 2) {
                //本周
                String monday = format.format(getThisWeekMonday(new Date())) + " 00:00:00";
                startTime = sdf.parse(monday).getTime();
            } else if (callValue == 3) {
                //当月
                Calendar c = Calendar.getInstance();
                c.add(Calendar.MONTH, 0);
                c.set(Calendar.DAY_OF_MONTH, 1);//设置为1号,当前日期既为本月第一天
                String first = format.format(c.getTime()) + " 00:00:00";
                startTime = sdf.parse(first).getTime();
            }
        }
        if (null != statusValue) {
            Calendar now = Calendar.getInstance();
            now.add(Calendar.DAY_OF_MONTH, -30);
            String day = format.format(now.getTime()) + " 00:00:00";
            startTime = sdf.parse(day).getTime();
        }

        return userMapper.listUsersByAdmin(tag, callValue, startTime, endTime, statusValue, alarmValue, roleType);
    }

    public Date getThisWeekMonday(Date date) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        // 获得当前日期是一个星期的第几天
        int dayWeek = cal.get(Calendar.DAY_OF_WEEK);
        if (1 == dayWeek) {
            cal.add(Calendar.DAY_OF_MONTH, -1);
        }
        // 设置一个星期的第一天，按中国的习惯一个星期的第一天是星期一
        cal.setFirstDayOfWeek(Calendar.MONDAY);
        // 获得当前日期是一个星期的第几天
        int day = cal.get(Calendar.DAY_OF_WEEK);
        // 根据日历的规则，给当前日期减去星期几与一个星期第一天的差值
        cal.add(Calendar.DATE, cal.getFirstDayOfWeek() - day);
        return cal.getTime();
    }

}
